# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from strmprivacy.api.agents.v1 import streams_agent_v1_pb2 as strmprivacy_dot_api_dot_agents_dot_v1_dot_streams__agent__v1__pb2


class StreamsAgentServiceStub(object):
    """(-- api-linter: core::0136::prepositions=disabled
    aip.dev/not-precedent: This is an internal API and the alternative with oneof is good either. --)
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetStreams = channel.unary_unary(
                '/strmprivacy.api.agents.v1.StreamsAgentService/GetStreams',
                request_serializer=strmprivacy_dot_api_dot_agents_dot_v1_dot_streams__agent__v1__pb2.GetStreamsRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_agents_dot_v1_dot_streams__agent__v1__pb2.GetStreamsResponse.FromString,
                )


class StreamsAgentServiceServicer(object):
    """(-- api-linter: core::0136::prepositions=disabled
    aip.dev/not-precedent: This is an internal API and the alternative with oneof is good either. --)
    """

    def GetStreams(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_StreamsAgentServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetStreams': grpc.unary_unary_rpc_method_handler(
                    servicer.GetStreams,
                    request_deserializer=strmprivacy_dot_api_dot_agents_dot_v1_dot_streams__agent__v1__pb2.GetStreamsRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_agents_dot_v1_dot_streams__agent__v1__pb2.GetStreamsResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'strmprivacy.api.agents.v1.StreamsAgentService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class StreamsAgentService(object):
    """(-- api-linter: core::0136::prepositions=disabled
    aip.dev/not-precedent: This is an internal API and the alternative with oneof is good either. --)
    """

    @staticmethod
    def GetStreams(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.agents.v1.StreamsAgentService/GetStreams',
            strmprivacy_dot_api_dot_agents_dot_v1_dot_streams__agent__v1__pb2.GetStreamsRequest.SerializeToString,
            strmprivacy_dot_api_dot_agents_dot_v1_dot_streams__agent__v1__pb2.GetStreamsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from strmprivacy.api.kafka_exporters.v1 import kafka_exporters_v1_pb2 as strmprivacy_dot_api_dot_kafka__exporters_dot_v1_dot_kafka__exporters__v1__pb2


class KafkaExportersServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListKafkaExporters = channel.unary_unary(
                '/strmprivacy.api.kafka_exporters.v1.KafkaExportersService/ListKafkaExporters',
                request_serializer=strmprivacy_dot_api_dot_kafka__exporters_dot_v1_dot_kafka__exporters__v1__pb2.ListKafkaExportersRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_kafka__exporters_dot_v1_dot_kafka__exporters__v1__pb2.ListKafkaExportersResponse.FromString,
                )
        self.GetKafkaExporter = channel.unary_unary(
                '/strmprivacy.api.kafka_exporters.v1.KafkaExportersService/GetKafkaExporter',
                request_serializer=strmprivacy_dot_api_dot_kafka__exporters_dot_v1_dot_kafka__exporters__v1__pb2.GetKafkaExporterRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_kafka__exporters_dot_v1_dot_kafka__exporters__v1__pb2.GetKafkaExporterResponse.FromString,
                )
        self.DeleteKafkaExporter = channel.unary_unary(
                '/strmprivacy.api.kafka_exporters.v1.KafkaExportersService/DeleteKafkaExporter',
                request_serializer=strmprivacy_dot_api_dot_kafka__exporters_dot_v1_dot_kafka__exporters__v1__pb2.DeleteKafkaExporterRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_kafka__exporters_dot_v1_dot_kafka__exporters__v1__pb2.DeleteKafkaExporterResponse.FromString,
                )
        self.CreateKafkaExporter = channel.unary_unary(
                '/strmprivacy.api.kafka_exporters.v1.KafkaExportersService/CreateKafkaExporter',
                request_serializer=strmprivacy_dot_api_dot_kafka__exporters_dot_v1_dot_kafka__exporters__v1__pb2.CreateKafkaExporterRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_kafka__exporters_dot_v1_dot_kafka__exporters__v1__pb2.CreateKafkaExporterResponse.FromString,
                )


class KafkaExportersServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ListKafkaExporters(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetKafkaExporter(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteKafkaExporter(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateKafkaExporter(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_KafkaExportersServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ListKafkaExporters': grpc.unary_unary_rpc_method_handler(
                    servicer.ListKafkaExporters,
                    request_deserializer=strmprivacy_dot_api_dot_kafka__exporters_dot_v1_dot_kafka__exporters__v1__pb2.ListKafkaExportersRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_kafka__exporters_dot_v1_dot_kafka__exporters__v1__pb2.ListKafkaExportersResponse.SerializeToString,
            ),
            'GetKafkaExporter': grpc.unary_unary_rpc_method_handler(
                    servicer.GetKafkaExporter,
                    request_deserializer=strmprivacy_dot_api_dot_kafka__exporters_dot_v1_dot_kafka__exporters__v1__pb2.GetKafkaExporterRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_kafka__exporters_dot_v1_dot_kafka__exporters__v1__pb2.GetKafkaExporterResponse.SerializeToString,
            ),
            'DeleteKafkaExporter': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteKafkaExporter,
                    request_deserializer=strmprivacy_dot_api_dot_kafka__exporters_dot_v1_dot_kafka__exporters__v1__pb2.DeleteKafkaExporterRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_kafka__exporters_dot_v1_dot_kafka__exporters__v1__pb2.DeleteKafkaExporterResponse.SerializeToString,
            ),
            'CreateKafkaExporter': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateKafkaExporter,
                    request_deserializer=strmprivacy_dot_api_dot_kafka__exporters_dot_v1_dot_kafka__exporters__v1__pb2.CreateKafkaExporterRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_kafka__exporters_dot_v1_dot_kafka__exporters__v1__pb2.CreateKafkaExporterResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'strmprivacy.api.kafka_exporters.v1.KafkaExportersService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class KafkaExportersService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ListKafkaExporters(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.kafka_exporters.v1.KafkaExportersService/ListKafkaExporters',
            strmprivacy_dot_api_dot_kafka__exporters_dot_v1_dot_kafka__exporters__v1__pb2.ListKafkaExportersRequest.SerializeToString,
            strmprivacy_dot_api_dot_kafka__exporters_dot_v1_dot_kafka__exporters__v1__pb2.ListKafkaExportersResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetKafkaExporter(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.kafka_exporters.v1.KafkaExportersService/GetKafkaExporter',
            strmprivacy_dot_api_dot_kafka__exporters_dot_v1_dot_kafka__exporters__v1__pb2.GetKafkaExporterRequest.SerializeToString,
            strmprivacy_dot_api_dot_kafka__exporters_dot_v1_dot_kafka__exporters__v1__pb2.GetKafkaExporterResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteKafkaExporter(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.kafka_exporters.v1.KafkaExportersService/DeleteKafkaExporter',
            strmprivacy_dot_api_dot_kafka__exporters_dot_v1_dot_kafka__exporters__v1__pb2.DeleteKafkaExporterRequest.SerializeToString,
            strmprivacy_dot_api_dot_kafka__exporters_dot_v1_dot_kafka__exporters__v1__pb2.DeleteKafkaExporterResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateKafkaExporter(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.kafka_exporters.v1.KafkaExportersService/CreateKafkaExporter',
            strmprivacy_dot_api_dot_kafka__exporters_dot_v1_dot_kafka__exporters__v1__pb2.CreateKafkaExporterRequest.SerializeToString,
            strmprivacy_dot_api_dot_kafka__exporters_dot_v1_dot_kafka__exporters__v1__pb2.CreateKafkaExporterResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strmprivacy/api/policies/v1/policies_v1.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from strmprivacy.api.entities.v1 import entities_v1_pb2 as strmprivacy_dot_api_dot_entities_dot_v1_dot_entities__v1__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-strmprivacy/api/policies/v1/policies_v1.proto\x12\x1bstrmprivacy.api.policies.v1\x1a\x1fgoogle/api/field_behavior.proto\x1a google/protobuf/field_mask.proto\x1a-strmprivacy/api/entities/v1/entities_v1.proto\x1a\x17validate/validate.proto\"\x15\n\x13ListPoliciesRequest\"W\n\x14ListPoliciesResponse\x12?\n\x08policies\x18\x01 \x03(\x0b\x32#.strmprivacy.api.entities.v1.PolicyR\x08policies\"<\n\x13\x44\x65letePolicyRequest\x12%\n\tpolicy_id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01R\x08policyId\"\x16\n\x14\x44\x65letePolicyResponse\"\\\n\x13\x43reatePolicyRequest\x12\x45\n\x06policy\x18\x01 \x01(\x0b\x32#.strmprivacy.api.entities.v1.PolicyB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\x06policy\"X\n\x14\x43reatePolicyResponse\x12@\n\x06policy\x18\x01 \x01(\x0b\x32#.strmprivacy.api.entities.v1.PolicyB\x03\xe0\x41\x02R\x06policy\"\xa3\x01\n\x13UpdatePolicyRequest\x12\x45\n\x06policy\x18\x01 \x01(\x0b\x32#.strmprivacy.api.entities.v1.PolicyB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\x06policy\x12\x45\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\nupdateMask\"X\n\x14UpdatePolicyResponse\x12@\n\x06policy\x18\x01 \x01(\x0b\x32#.strmprivacy.api.entities.v1.PolicyB\x03\xe0\x41\x02R\x06policy\"<\n\x10GetPolicyRequest\x12(\n\tpolicy_id\x18\x01 \x01(\tB\x0b\xfa\x42\x08r\x06\xd0\x01\x01\xb0\x01\x01R\x08policyId\"P\n\x11GetPolicyResponse\x12;\n\x06policy\x18\x01 \x01(\x0b\x32#.strmprivacy.api.entities.v1.PolicyR\x06policy2\xd1\x04\n\x0fPoliciesService\x12s\n\x0cListPolicies\x12\x30.strmprivacy.api.policies.v1.ListPoliciesRequest\x1a\x31.strmprivacy.api.policies.v1.ListPoliciesResponse\x12j\n\tGetPolicy\x12-.strmprivacy.api.policies.v1.GetPolicyRequest\x1a..strmprivacy.api.policies.v1.GetPolicyResponse\x12s\n\x0c\x44\x65letePolicy\x12\x30.strmprivacy.api.policies.v1.DeletePolicyRequest\x1a\x31.strmprivacy.api.policies.v1.DeletePolicyResponse\x12s\n\x0c\x43reatePolicy\x12\x30.strmprivacy.api.policies.v1.CreatePolicyRequest\x1a\x31.strmprivacy.api.policies.v1.CreatePolicyResponse\x12s\n\x0cUpdatePolicy\x12\x30.strmprivacy.api.policies.v1.UpdatePolicyRequest\x1a\x31.strmprivacy.api.policies.v1.UpdatePolicyResponseBi\n\x1eio.strmprivacy.api.policies.v1P\x01ZEgithub.com/strmprivacy/api-definitions-go/v2/api/policies/v1;policiesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'strmprivacy.api.policies.v1.policies_v1_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\036io.strmprivacy.api.policies.v1P\001ZEgithub.com/strmprivacy/api-definitions-go/v2/api/policies/v1;policies'
  _DELETEPOLICYREQUEST.fields_by_name['policy_id']._options = None
  _DELETEPOLICYREQUEST.fields_by_name['policy_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _CREATEPOLICYREQUEST.fields_by_name['policy']._options = None
  _CREATEPOLICYREQUEST.fields_by_name['policy']._serialized_options = b'\372B\005\212\001\002\020\001'
  _CREATEPOLICYRESPONSE.fields_by_name['policy']._options = None
  _CREATEPOLICYRESPONSE.fields_by_name['policy']._serialized_options = b'\340A\002'
  _UPDATEPOLICYREQUEST.fields_by_name['policy']._options = None
  _UPDATEPOLICYREQUEST.fields_by_name['policy']._serialized_options = b'\372B\005\212\001\002\020\001'
  _UPDATEPOLICYREQUEST.fields_by_name['update_mask']._options = None
  _UPDATEPOLICYREQUEST.fields_by_name['update_mask']._serialized_options = b'\372B\005\212\001\002\020\001'
  _UPDATEPOLICYRESPONSE.fields_by_name['policy']._options = None
  _UPDATEPOLICYRESPONSE.fields_by_name['policy']._serialized_options = b'\340A\002'
  _GETPOLICYREQUEST.fields_by_name['policy_id']._options = None
  _GETPOLICYREQUEST.fields_by_name['policy_id']._serialized_options = b'\372B\010r\006\320\001\001\260\001\001'
  _LISTPOLICIESREQUEST._serialized_start=217
  _LISTPOLICIESREQUEST._serialized_end=238
  _LISTPOLICIESRESPONSE._serialized_start=240
  _LISTPOLICIESRESPONSE._serialized_end=327
  _DELETEPOLICYREQUEST._serialized_start=329
  _DELETEPOLICYREQUEST._serialized_end=389
  _DELETEPOLICYRESPONSE._serialized_start=391
  _DELETEPOLICYRESPONSE._serialized_end=413
  _CREATEPOLICYREQUEST._serialized_start=415
  _CREATEPOLICYREQUEST._serialized_end=507
  _CREATEPOLICYRESPONSE._serialized_start=509
  _CREATEPOLICYRESPONSE._serialized_end=597
  _UPDATEPOLICYREQUEST._serialized_start=600
  _UPDATEPOLICYREQUEST._serialized_end=763
  _UPDATEPOLICYRESPONSE._serialized_start=765
  _UPDATEPOLICYRESPONSE._serialized_end=853
  _GETPOLICYREQUEST._serialized_start=855
  _GETPOLICYREQUEST._serialized_end=915
  _GETPOLICYRESPONSE._serialized_start=917
  _GETPOLICYRESPONSE._serialized_end=997
  _POLICIESSERVICE._serialized_start=1000
  _POLICIESSERVICE._serialized_end=1593
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from strmprivacy.api.kafka_users.v1 import kafka_users_v1_pb2 as strmprivacy_dot_api_dot_kafka__users_dot_v1_dot_kafka__users__v1__pb2


class KafkaUsersServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListKafkaUsers = channel.unary_unary(
                '/strmprivacy.api.kafka_users.v1.KafkaUsersService/ListKafkaUsers',
                request_serializer=strmprivacy_dot_api_dot_kafka__users_dot_v1_dot_kafka__users__v1__pb2.ListKafkaUsersRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_kafka__users_dot_v1_dot_kafka__users__v1__pb2.ListKafkaUsersResponse.FromString,
                )
        self.GetKafkaUser = channel.unary_unary(
                '/strmprivacy.api.kafka_users.v1.KafkaUsersService/GetKafkaUser',
                request_serializer=strmprivacy_dot_api_dot_kafka__users_dot_v1_dot_kafka__users__v1__pb2.GetKafkaUserRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_kafka__users_dot_v1_dot_kafka__users__v1__pb2.GetKafkaUserResponse.FromString,
                )
        self.DeleteKafkaUser = channel.unary_unary(
                '/strmprivacy.api.kafka_users.v1.KafkaUsersService/DeleteKafkaUser',
                request_serializer=strmprivacy_dot_api_dot_kafka__users_dot_v1_dot_kafka__users__v1__pb2.DeleteKafkaUserRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_kafka__users_dot_v1_dot_kafka__users__v1__pb2.DeleteKafkaUserResponse.FromString,
                )
        self.CreateKafkaUser = channel.unary_unary(
                '/strmprivacy.api.kafka_users.v1.KafkaUsersService/CreateKafkaUser',
                request_serializer=strmprivacy_dot_api_dot_kafka__users_dot_v1_dot_kafka__users__v1__pb2.CreateKafkaUserRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_kafka__users_dot_v1_dot_kafka__users__v1__pb2.CreateKafkaUserResponse.FromString,
                )


class KafkaUsersServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ListKafkaUsers(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetKafkaUser(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteKafkaUser(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateKafkaUser(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_KafkaUsersServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ListKafkaUsers': grpc.unary_unary_rpc_method_handler(
                    servicer.ListKafkaUsers,
                    request_deserializer=strmprivacy_dot_api_dot_kafka__users_dot_v1_dot_kafka__users__v1__pb2.ListKafkaUsersRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_kafka__users_dot_v1_dot_kafka__users__v1__pb2.ListKafkaUsersResponse.SerializeToString,
            ),
            'GetKafkaUser': grpc.unary_unary_rpc_method_handler(
                    servicer.GetKafkaUser,
                    request_deserializer=strmprivacy_dot_api_dot_kafka__users_dot_v1_dot_kafka__users__v1__pb2.GetKafkaUserRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_kafka__users_dot_v1_dot_kafka__users__v1__pb2.GetKafkaUserResponse.SerializeToString,
            ),
            'DeleteKafkaUser': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteKafkaUser,
                    request_deserializer=strmprivacy_dot_api_dot_kafka__users_dot_v1_dot_kafka__users__v1__pb2.DeleteKafkaUserRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_kafka__users_dot_v1_dot_kafka__users__v1__pb2.DeleteKafkaUserResponse.SerializeToString,
            ),
            'CreateKafkaUser': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateKafkaUser,
                    request_deserializer=strmprivacy_dot_api_dot_kafka__users_dot_v1_dot_kafka__users__v1__pb2.CreateKafkaUserRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_kafka__users_dot_v1_dot_kafka__users__v1__pb2.CreateKafkaUserResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'strmprivacy.api.kafka_users.v1.KafkaUsersService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class KafkaUsersService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ListKafkaUsers(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.kafka_users.v1.KafkaUsersService/ListKafkaUsers',
            strmprivacy_dot_api_dot_kafka__users_dot_v1_dot_kafka__users__v1__pb2.ListKafkaUsersRequest.SerializeToString,
            strmprivacy_dot_api_dot_kafka__users_dot_v1_dot_kafka__users__v1__pb2.ListKafkaUsersResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetKafkaUser(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.kafka_users.v1.KafkaUsersService/GetKafkaUser',
            strmprivacy_dot_api_dot_kafka__users_dot_v1_dot_kafka__users__v1__pb2.GetKafkaUserRequest.SerializeToString,
            strmprivacy_dot_api_dot_kafka__users_dot_v1_dot_kafka__users__v1__pb2.GetKafkaUserResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteKafkaUser(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.kafka_users.v1.KafkaUsersService/DeleteKafkaUser',
            strmprivacy_dot_api_dot_kafka__users_dot_v1_dot_kafka__users__v1__pb2.DeleteKafkaUserRequest.SerializeToString,
            strmprivacy_dot_api_dot_kafka__users_dot_v1_dot_kafka__users__v1__pb2.DeleteKafkaUserResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateKafkaUser(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.kafka_users.v1.KafkaUsersService/CreateKafkaUser',
            strmprivacy_dot_api_dot_kafka__users_dot_v1_dot_kafka__users__v1__pb2.CreateKafkaUserRequest.SerializeToString,
            strmprivacy_dot_api_dot_kafka__users_dot_v1_dot_kafka__users__v1__pb2.CreateKafkaUserResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strmprivacy/api/account/v1/account_v1.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+strmprivacy/api/account/v1/account_v1.proto\x12\x1astrmprivacy.api.account.v1\x1a\x1fgoogle/api/field_behavior.proto\x1a\x17validate/validate.proto\"H\n\x18GetAccountDetailsRequest\x12,\n\nbilling_id\x18\x01 \x01(\tB\r\x18\x01\xfa\x42\x08r\x06\x98\x01\x00\xd0\x01\x01R\tbillingId\"\xbb\x02\n\x19GetAccountDetailsResponse\x12!\n\nbilling_id\x18\x01 \x01(\tB\x02\x18\x01R\tbillingId\x12/\n\x11max_input_streams\x18\x02 \x01(\x05\x42\x03\xe0\x41\x02R\x0fmaxInputStreams\x12\x1b\n\x06handle\x18\x03 \x01(\tB\x03\xe0\x41\x01R\x06handle\x12\'\n\x0csubscription\x18\x04 \x01(\tB\x03\xe0\x41\x02R\x0csubscription\x12\'\n\x0corganization\x18\x05 \x01(\tB\x03\xe0\x41\x02R\x0corganization\x12,\n\x0forganization_id\x18\x06 \x01(\tB\x03\xe0\x41\x02R\x0eorganizationId\x12-\n\x10internal_user_id\x18\x07 \x01(\tB\x03\xe0\x41\x02R\x0einternalUserId\"\x1f\n\x19GetLegacyBillingIdRequest:\x02\x18\x01\"D\n\x1aGetLegacyBillingIdResponse\x12\"\n\nbilling_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\tbillingId:\x02\x18\x01\"\x9c\x01\n\x1a\x43reateAccountHandleRequest\x12,\n\nbilling_id\x18\x01 \x01(\tB\r\x18\x01\xfa\x42\x08r\x06\x98\x01\x00\xd0\x01\x01R\tbillingId\x12P\n\x06handle\x18\x02 \x01(\tB8\xfa\x42\x35r3\x10\x04\x18\x64\x32&^[a-zA-Z0-9][a-zA-Z0-9_-]+[a-zA-Z0-9]$\xba\x01\x04strmR\x06handle\":\n\x1b\x43reateAccountHandleResponse\x12\x1b\n\x06handle\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x06handle\"\x8e\x01\n\x19InitializeCheckoutRequest\x12I\n\x07plan_id\x18\x01 \x01(\tB0\xfa\x42-r+\x10\x01R\nENTERPRISER\x08\x42USINESSR\x0bSELF_HOSTEDR\x04\x46REER\x06planId\x12&\n\x07user_id\x18\x02 \x01(\tB\r\x18\x01\xfa\x42\x08r\x06\x98\x01\x00\xd0\x01\x01R\x06userId\"D\n\x1aInitializeCheckoutResponse\x12&\n\x0c\x63heckout_uri\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x0b\x63heckoutUri\"~\n\x18GetCheckoutStatusRequest\x12&\n\x07user_id\x18\x01 \x01(\tB\r\x18\x01\xfa\x42\x08r\x06\x98\x01\x00\xd0\x01\x01R\x06userId\x12:\n\x13\x63heckout_session_id\x18\x02 \x01(\tB\n\xfa\x42\x07r\x05\x10\x01\xd0\x01\x01R\x11\x63heckoutSessionId\"8\n\x19GetCheckoutStatusResponse\x12\x1b\n\x06status\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x06status\"\x81\x01\n\x1bSetCheckoutCancelledRequest\x12&\n\x07user_id\x18\x01 \x01(\tB\r\x18\x01\xfa\x42\x08r\x06\x98\x01\x00\xd0\x01\x01R\x06userId\x12:\n\x13\x63heckout_session_id\x18\x02 \x01(\tB\n\xfa\x42\x07r\x05\x10\x01\xd0\x01\x01R\x11\x63heckoutSessionId\"\x1e\n\x1cSetCheckoutCancelledResponse\"I\n\x1fInitializeCustomerPortalRequest\x12&\n\x07user_id\x18\x01 \x01(\tB\r\x18\x01\xfa\x42\x08r\x06\x98\x01\x00\xd0\x01\x01R\x06userId\"W\n InitializeCustomerPortalResponse\x12\x33\n\x13\x63ustomer_portal_uri\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x11\x63ustomerPortalUri2\xcf\x07\n\x0e\x41\x63\x63ountService\x12\x80\x01\n\x11GetAccountDetails\x12\x34.strmprivacy.api.account.v1.GetAccountDetailsRequest\x1a\x35.strmprivacy.api.account.v1.GetAccountDetailsResponse\x12\x83\x01\n\x12GetLegacyBillingId\x12\x35.strmprivacy.api.account.v1.GetLegacyBillingIdRequest\x1a\x36.strmprivacy.api.account.v1.GetLegacyBillingIdResponse\x12\x86\x01\n\x13\x43reateAccountHandle\x12\x36.strmprivacy.api.account.v1.CreateAccountHandleRequest\x1a\x37.strmprivacy.api.account.v1.CreateAccountHandleResponse\x12\x83\x01\n\x12InitializeCheckout\x12\x35.strmprivacy.api.account.v1.InitializeCheckoutRequest\x1a\x36.strmprivacy.api.account.v1.InitializeCheckoutResponse\x12\x80\x01\n\x11GetCheckoutStatus\x12\x34.strmprivacy.api.account.v1.GetCheckoutStatusRequest\x1a\x35.strmprivacy.api.account.v1.GetCheckoutStatusResponse\x12\x95\x01\n\x18InitializeCustomerPortal\x12;.strmprivacy.api.account.v1.InitializeCustomerPortalRequest\x1a<.strmprivacy.api.account.v1.InitializeCustomerPortalResponse\x12\x89\x01\n\x14SetCheckoutCancelled\x12\x37.strmprivacy.api.account.v1.SetCheckoutCancelledRequest\x1a\x38.strmprivacy.api.account.v1.SetCheckoutCancelledResponseBf\n\x1dio.strmprivacy.api.account.v1P\x01ZCgithub.com/strmprivacy/api-definitions-go/v2/api/account/v1;accountb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'strmprivacy.api.account.v1.account_v1_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\035io.strmprivacy.api.account.v1P\001ZCgithub.com/strmprivacy/api-definitions-go/v2/api/account/v1;account'
  _GETACCOUNTDETAILSREQUEST.fields_by_name['billing_id']._options = None
  _GETACCOUNTDETAILSREQUEST.fields_by_name['billing_id']._serialized_options = b'\030\001\372B\010r\006\230\001\000\320\001\001'
  _GETACCOUNTDETAILSRESPONSE.fields_by_name['billing_id']._options = None
  _GETACCOUNTDETAILSRESPONSE.fields_by_name['billing_id']._serialized_options = b'\030\001'
  _GETACCOUNTDETAILSRESPONSE.fields_by_name['max_input_streams']._options = None
  _GETACCOUNTDETAILSRESPONSE.fields_by_name['max_input_streams']._serialized_options = b'\340A\002'
  _GETACCOUNTDETAILSRESPONSE.fields_by_name['handle']._options = None
  _GETACCOUNTDETAILSRESPONSE.fields_by_name['handle']._serialized_options = b'\340A\001'
  _GETACCOUNTDETAILSRESPONSE.fields_by_name['subscription']._options = None
  _GETACCOUNTDETAILSRESPONSE.fields_by_name['subscription']._serialized_options = b'\340A\002'
  _GETACCOUNTDETAILSRESPONSE.fields_by_name['organization']._options = None
  _GETACCOUNTDETAILSRESPONSE.fields_by_name['organization']._serialized_options = b'\340A\002'
  _GETACCOUNTDETAILSRESPONSE.fields_by_name['organization_id']._options = None
  _GETACCOUNTDETAILSRESPONSE.fields_by_name['organization_id']._serialized_options = b'\340A\002'
  _GETACCOUNTDETAILSRESPONSE.fields_by_name['internal_user_id']._options = None
  _GETACCOUNTDETAILSRESPONSE.fields_by_name['internal_user_id']._serialized_options = b'\340A\002'
  _GETLEGACYBILLINGIDREQUEST._options = None
  _GETLEGACYBILLINGIDREQUEST._serialized_options = b'\030\001'
  _GETLEGACYBILLINGIDRESPONSE.fields_by_name['billing_id']._options = None
  _GETLEGACYBILLINGIDRESPONSE.fields_by_name['billing_id']._serialized_options = b'\340A\002'
  _GETLEGACYBILLINGIDRESPONSE._options = None
  _GETLEGACYBILLINGIDRESPONSE._serialized_options = b'\030\001'
  _CREATEACCOUNTHANDLEREQUEST.fields_by_name['billing_id']._options = None
  _CREATEACCOUNTHANDLEREQUEST.fields_by_name['billing_id']._serialized_options = b'\030\001\372B\010r\006\230\001\000\320\001\001'
  _CREATEACCOUNTHANDLEREQUEST.fields_by_name['handle']._options = None
  _CREATEACCOUNTHANDLEREQUEST.fields_by_name['handle']._serialized_options = b'\372B5r3\020\004\030d2&^[a-zA-Z0-9][a-zA-Z0-9_-]+[a-zA-Z0-9]$\272\001\004strm'
  _CREATEACCOUNTHANDLERESPONSE.fields_by_name['handle']._options = None
  _CREATEACCOUNTHANDLERESPONSE.fields_by_name['handle']._serialized_options = b'\340A\002'
  _INITIALIZECHECKOUTREQUEST.fields_by_name['plan_id']._options = None
  _INITIALIZECHECKOUTREQUEST.fields_by_name['plan_id']._serialized_options = b'\372B-r+\020\001R\nENTERPRISER\010BUSINESSR\013SELF_HOSTEDR\004FREE'
  _INITIALIZECHECKOUTREQUEST.fields_by_name['user_id']._options = None
  _INITIALIZECHECKOUTREQUEST.fields_by_name['user_id']._serialized_options = b'\030\001\372B\010r\006\230\001\000\320\001\001'
  _INITIALIZECHECKOUTRESPONSE.fields_by_name['checkout_uri']._options = None
  _INITIALIZECHECKOUTRESPONSE.fields_by_name['checkout_uri']._serialized_options = b'\340A\002'
  _GETCHECKOUTSTATUSREQUEST.fields_by_name['user_id']._options = None
  _GETCHECKOUTSTATUSREQUEST.fields_by_name['user_id']._serialized_options = b'\030\001\372B\010r\006\230\001\000\320\001\001'
  _GETCHECKOUTSTATUSREQUEST.fields_by_name['checkout_session_id']._options = None
  _GETCHECKOUTSTATUSREQUEST.fields_by_name['checkout_session_id']._serialized_options = b'\372B\007r\005\020\001\320\001\001'
  _GETCHECKOUTSTATUSRESPONSE.fields_by_name['status']._options = None
  _GETCHECKOUTSTATUSRESPONSE.fields_by_name['status']._serialized_options = b'\340A\002'
  _SETCHECKOUTCANCELLEDREQUEST.fields_by_name['user_id']._options = None
  _SETCHECKOUTCANCELLEDREQUEST.fields_by_name['user_id']._serialized_options = b'\030\001\372B\010r\006\230\001\000\320\001\001'
  _SETCHECKOUTCANCELLEDREQUEST.fields_by_name['checkout_session_id']._options = None
  _SETCHECKOUTCANCELLEDREQUEST.fields_by_name['checkout_session_id']._serialized_options = b'\372B\007r\005\020\001\320\001\001'
  _INITIALIZECUSTOMERPORTALREQUEST.fields_by_name['user_id']._options = None
  _INITIALIZECUSTOMERPORTALREQUEST.fields_by_name['user_id']._serialized_options = b'\030\001\372B\010r\006\230\001\000\320\001\001'
  _INITIALIZECUSTOMERPORTALRESPONSE.fields_by_name['customer_portal_uri']._options = None
  _INITIALIZECUSTOMERPORTALRESPONSE.fields_by_name['customer_portal_uri']._serialized_options = b'\340A\002'
  _GETACCOUNTDETAILSREQUEST._serialized_start=133
  _GETACCOUNTDETAILSREQUEST._serialized_end=205
  _GETACCOUNTDETAILSRESPONSE._serialized_start=208
  _GETACCOUNTDETAILSRESPONSE._serialized_end=523
  _GETLEGACYBILLINGIDREQUEST._serialized_start=525
  _GETLEGACYBILLINGIDREQUEST._serialized_end=556
  _GETLEGACYBILLINGIDRESPONSE._serialized_start=558
  _GETLEGACYBILLINGIDRESPONSE._serialized_end=626
  _CREATEACCOUNTHANDLEREQUEST._serialized_start=629
  _CREATEACCOUNTHANDLEREQUEST._serialized_end=785
  _CREATEACCOUNTHANDLERESPONSE._serialized_start=787
  _CREATEACCOUNTHANDLERESPONSE._serialized_end=845
  _INITIALIZECHECKOUTREQUEST._serialized_start=848
  _INITIALIZECHECKOUTREQUEST._serialized_end=990
  _INITIALIZECHECKOUTRESPONSE._serialized_start=992
  _INITIALIZECHECKOUTRESPONSE._serialized_end=1060
  _GETCHECKOUTSTATUSREQUEST._serialized_start=1062
  _GETCHECKOUTSTATUSREQUEST._serialized_end=1188
  _GETCHECKOUTSTATUSRESPONSE._serialized_start=1190
  _GETCHECKOUTSTATUSRESPONSE._serialized_end=1246
  _SETCHECKOUTCANCELLEDREQUEST._serialized_start=1249
  _SETCHECKOUTCANCELLEDREQUEST._serialized_end=1378
  _SETCHECKOUTCANCELLEDRESPONSE._serialized_start=1380
  _SETCHECKOUTCANCELLEDRESPONSE._serialized_end=1410
  _INITIALIZECUSTOMERPORTALREQUEST._serialized_start=1412
  _INITIALIZECUSTOMERPORTALREQUEST._serialized_end=1485
  _INITIALIZECUSTOMERPORTALRESPONSE._serialized_start=1487
  _INITIALIZECUSTOMERPORTALRESPONSE._serialized_end=1574
  _ACCOUNTSERVICE._serialized_start=1577
  _ACCOUNTSERVICE._serialized_end=2552
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strmprivacy/api/projects/v1/projects_v1.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from strmprivacy.api.entities.v1 import entities_v1_pb2 as strmprivacy_dot_api_dot_entities_dot_v1_dot_entities__v1__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-strmprivacy/api/projects/v1/projects_v1.proto\x12\x1bstrmprivacy.api.projects.v1\x1a\x1fgoogle/api/field_behavior.proto\x1a-strmprivacy/api/entities/v1/entities_v1.proto\x1a\x17validate/validate.proto\"<\n\x11GetProjectRequest\x12\'\n\nproject_id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01R\tprojectId\"Y\n\x12GetProjectResponse\x12\x43\n\x07project\x18\x01 \x01(\x0b\x32$.strmprivacy.api.entities.v1.ProjectB\x03\xe0\x41\x02R\x07project\"\x15\n\x13ListProjectsRequest\"X\n\x14ListProjectsResponse\x12@\n\x08projects\x18\x01 \x03(\x0b\x32$.strmprivacy.api.entities.v1.ProjectR\x08projects\"`\n\x14\x43reateProjectRequest\x12H\n\x07project\x18\x01 \x01(\x0b\x32$.strmprivacy.api.entities.v1.ProjectB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\x07project\"\\\n\x15\x43reateProjectResponse\x12\x43\n\x07project\x18\x01 \x01(\x0b\x32$.strmprivacy.api.entities.v1.ProjectB\x03\xe0\x41\x02R\x07project\"?\n\x14\x44\x65leteProjectRequest\x12\'\n\nproject_id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01R\tprojectId\"\x17\n\x15\x44\x65leteProjectResponse\"k\n\x18\x41\x64\x64ProjectMembersRequest\x12&\n\x06\x65mails\x18\x01 \x03(\tB\x0e\xfa\x42\x0b\x92\x01\x08\x08\x01\"\x04r\x02`\x01R\x06\x65mails\x12\'\n\nproject_id\x18\x02 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01R\tprojectId\"\x1b\n\x19\x41\x64\x64ProjectMembersResponse\"n\n\x1bRemoveProjectMembersRequest\x12&\n\x06\x65mails\x18\x01 \x03(\tB\x0e\xfa\x42\x0b\x92\x01\x08\x08\x01\"\x04r\x02`\x01R\x06\x65mails\x12\'\n\nproject_id\x18\x02 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01R\tprojectId\"\x1e\n\x1cRemoveProjectMembersResponse\"D\n\x19ListProjectMembersRequest\x12\'\n\nproject_id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01R\tprojectId\"h\n\x1aListProjectMembersResponse\x12J\n\x0fproject_members\x18\x01 \x03(\x0b\x32!.strmprivacy.api.entities.v1.UserR\x0eprojectMembers2\x80\x07\n\x0fProjectsService\x12s\n\x0cListProjects\x12\x30.strmprivacy.api.projects.v1.ListProjectsRequest\x1a\x31.strmprivacy.api.projects.v1.ListProjectsResponse\x12v\n\rCreateProject\x12\x31.strmprivacy.api.projects.v1.CreateProjectRequest\x1a\x32.strmprivacy.api.projects.v1.CreateProjectResponse\x12v\n\rDeleteProject\x12\x31.strmprivacy.api.projects.v1.DeleteProjectRequest\x1a\x32.strmprivacy.api.projects.v1.DeleteProjectResponse\x12m\n\nGetProject\x12..strmprivacy.api.projects.v1.GetProjectRequest\x1a/.strmprivacy.api.projects.v1.GetProjectResponse\x12\x82\x01\n\x11\x41\x64\x64ProjectMembers\x12\x35.strmprivacy.api.projects.v1.AddProjectMembersRequest\x1a\x36.strmprivacy.api.projects.v1.AddProjectMembersResponse\x12\x8b\x01\n\x14RemoveProjectMembers\x12\x38.strmprivacy.api.projects.v1.RemoveProjectMembersRequest\x1a\x39.strmprivacy.api.projects.v1.RemoveProjectMembersResponse\x12\x85\x01\n\x12ListProjectMembers\x12\x36.strmprivacy.api.projects.v1.ListProjectMembersRequest\x1a\x37.strmprivacy.api.projects.v1.ListProjectMembersResponseBi\n\x1eio.strmprivacy.api.projects.v1P\x01ZEgithub.com/strmprivacy/api-definitions-go/v2/api/projects/v1;projectsb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'strmprivacy.api.projects.v1.projects_v1_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\036io.strmprivacy.api.projects.v1P\001ZEgithub.com/strmprivacy/api-definitions-go/v2/api/projects/v1;projects'
  _GETPROJECTREQUEST.fields_by_name['project_id']._options = None
  _GETPROJECTREQUEST.fields_by_name['project_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _GETPROJECTRESPONSE.fields_by_name['project']._options = None
  _GETPROJECTRESPONSE.fields_by_name['project']._serialized_options = b'\340A\002'
  _CREATEPROJECTREQUEST.fields_by_name['project']._options = None
  _CREATEPROJECTREQUEST.fields_by_name['project']._serialized_options = b'\372B\005\212\001\002\020\001'
  _CREATEPROJECTRESPONSE.fields_by_name['project']._options = None
  _CREATEPROJECTRESPONSE.fields_by_name['project']._serialized_options = b'\340A\002'
  _DELETEPROJECTREQUEST.fields_by_name['project_id']._options = None
  _DELETEPROJECTREQUEST.fields_by_name['project_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _ADDPROJECTMEMBERSREQUEST.fields_by_name['emails']._options = None
  _ADDPROJECTMEMBERSREQUEST.fields_by_name['emails']._serialized_options = b'\372B\013\222\001\010\010\001\"\004r\002`\001'
  _ADDPROJECTMEMBERSREQUEST.fields_by_name['project_id']._options = None
  _ADDPROJECTMEMBERSREQUEST.fields_by_name['project_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _REMOVEPROJECTMEMBERSREQUEST.fields_by_name['emails']._options = None
  _REMOVEPROJECTMEMBERSREQUEST.fields_by_name['emails']._serialized_options = b'\372B\013\222\001\010\010\001\"\004r\002`\001'
  _REMOVEPROJECTMEMBERSREQUEST.fields_by_name['project_id']._options = None
  _REMOVEPROJECTMEMBERSREQUEST.fields_by_name['project_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _LISTPROJECTMEMBERSREQUEST.fields_by_name['project_id']._options = None
  _LISTPROJECTMEMBERSREQUEST.fields_by_name['project_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _GETPROJECTREQUEST._serialized_start=183
  _GETPROJECTREQUEST._serialized_end=243
  _GETPROJECTRESPONSE._serialized_start=245
  _GETPROJECTRESPONSE._serialized_end=334
  _LISTPROJECTSREQUEST._serialized_start=336
  _LISTPROJECTSREQUEST._serialized_end=357
  _LISTPROJECTSRESPONSE._serialized_start=359
  _LISTPROJECTSRESPONSE._serialized_end=447
  _CREATEPROJECTREQUEST._serialized_start=449
  _CREATEPROJECTREQUEST._serialized_end=545
  _CREATEPROJECTRESPONSE._serialized_start=547
  _CREATEPROJECTRESPONSE._serialized_end=639
  _DELETEPROJECTREQUEST._serialized_start=641
  _DELETEPROJECTREQUEST._serialized_end=704
  _DELETEPROJECTRESPONSE._serialized_start=706
  _DELETEPROJECTRESPONSE._serialized_end=729
  _ADDPROJECTMEMBERSREQUEST._serialized_start=731
  _ADDPROJECTMEMBERSREQUEST._serialized_end=838
  _ADDPROJECTMEMBERSRESPONSE._serialized_start=840
  _ADDPROJECTMEMBERSRESPONSE._serialized_end=867
  _REMOVEPROJECTMEMBERSREQUEST._serialized_start=869
  _REMOVEPROJECTMEMBERSREQUEST._serialized_end=979
  _REMOVEPROJECTMEMBERSRESPONSE._serialized_start=981
  _REMOVEPROJECTMEMBERSRESPONSE._serialized_end=1011
  _LISTPROJECTMEMBERSREQUEST._serialized_start=1013
  _LISTPROJECTMEMBERSREQUEST._serialized_end=1081
  _LISTPROJECTMEMBERSRESPONSE._serialized_start=1083
  _LISTPROJECTMEMBERSRESPONSE._serialized_end=1187
  _PROJECTSSERVICE._serialized_start=1190
  _PROJECTSSERVICE._serialized_end=2086
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from strmprivacy.api.monitoring.v1 import monitoring_pb2 as strmprivacy_dot_api_dot_monitoring_dot_v1_dot_monitoring__pb2


class MonitoringServiceStub(object):
    """
    The monitoring service
    1. holds a semi-persistent store of entity states that can be queried by end users to show entity state
    2. has an endpoint that agents can call to store entity states
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetEntityState = channel.unary_stream(
                '/strmprivacy.api.monitoring.v1.MonitoringService/GetEntityState',
                request_serializer=strmprivacy_dot_api_dot_monitoring_dot_v1_dot_monitoring__pb2.GetEntityStateRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_monitoring_dot_v1_dot_monitoring__pb2.GetEntityStateResponse.FromString,
                )
        self.GetLatestEntityStates = channel.unary_unary(
                '/strmprivacy.api.monitoring.v1.MonitoringService/GetLatestEntityStates',
                request_serializer=strmprivacy_dot_api_dot_monitoring_dot_v1_dot_monitoring__pb2.GetLatestEntityStatesRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_monitoring_dot_v1_dot_monitoring__pb2.GetLatestEntityStatesResponse.FromString,
                )
        self.UpdateEntityStates = channel.stream_unary(
                '/strmprivacy.api.monitoring.v1.MonitoringService/UpdateEntityStates',
                request_serializer=strmprivacy_dot_api_dot_monitoring_dot_v1_dot_monitoring__pb2.UpdateEntityStatesRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_monitoring_dot_v1_dot_monitoring__pb2.UpdateEntityStatesResponse.FromString,
                )


class MonitoringServiceServicer(object):
    """
    The monitoring service
    1. holds a semi-persistent store of entity states that can be queried by end users to show entity state
    2. has an endpoint that agents can call to store entity states
    """

    def GetEntityState(self, request, context):
        """
        will be called by end users from the cli or console, to retrieve entity states
        and indicate them to users.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetLatestEntityStates(self, request, context):
        """
        can be called via the CLI and the Console, to get the latest entity state for all entities included
        in this request
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateEntityStates(self, request_iterator, context):
        """
        will be called from entity agents so that they can send the entity states
        of items they're responsible for to the monitoring service.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_MonitoringServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetEntityState': grpc.unary_stream_rpc_method_handler(
                    servicer.GetEntityState,
                    request_deserializer=strmprivacy_dot_api_dot_monitoring_dot_v1_dot_monitoring__pb2.GetEntityStateRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_monitoring_dot_v1_dot_monitoring__pb2.GetEntityStateResponse.SerializeToString,
            ),
            'GetLatestEntityStates': grpc.unary_unary_rpc_method_handler(
                    servicer.GetLatestEntityStates,
                    request_deserializer=strmprivacy_dot_api_dot_monitoring_dot_v1_dot_monitoring__pb2.GetLatestEntityStatesRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_monitoring_dot_v1_dot_monitoring__pb2.GetLatestEntityStatesResponse.SerializeToString,
            ),
            'UpdateEntityStates': grpc.stream_unary_rpc_method_handler(
                    servicer.UpdateEntityStates,
                    request_deserializer=strmprivacy_dot_api_dot_monitoring_dot_v1_dot_monitoring__pb2.UpdateEntityStatesRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_monitoring_dot_v1_dot_monitoring__pb2.UpdateEntityStatesResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'strmprivacy.api.monitoring.v1.MonitoringService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class MonitoringService(object):
    """
    The monitoring service
    1. holds a semi-persistent store of entity states that can be queried by end users to show entity state
    2. has an endpoint that agents can call to store entity states
    """

    @staticmethod
    def GetEntityState(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/strmprivacy.api.monitoring.v1.MonitoringService/GetEntityState',
            strmprivacy_dot_api_dot_monitoring_dot_v1_dot_monitoring__pb2.GetEntityStateRequest.SerializeToString,
            strmprivacy_dot_api_dot_monitoring_dot_v1_dot_monitoring__pb2.GetEntityStateResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetLatestEntityStates(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.monitoring.v1.MonitoringService/GetLatestEntityStates',
            strmprivacy_dot_api_dot_monitoring_dot_v1_dot_monitoring__pb2.GetLatestEntityStatesRequest.SerializeToString,
            strmprivacy_dot_api_dot_monitoring_dot_v1_dot_monitoring__pb2.GetLatestEntityStatesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateEntityStates(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_unary(request_iterator, target, '/strmprivacy.api.monitoring.v1.MonitoringService/UpdateEntityStates',
            strmprivacy_dot_api_dot_monitoring_dot_v1_dot_monitoring__pb2.UpdateEntityStatesRequest.SerializeToString,
            strmprivacy_dot_api_dot_monitoring_dot_v1_dot_monitoring__pb2.UpdateEntityStatesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from strmprivacy.api.purpose_mapping.v1 import purpose_mapping_v1_pb2 as strmprivacy_dot_api_dot_purpose__mapping_dot_v1_dot_purpose__mapping__v1__pb2


class PurposeMappingServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListPurposeMappings = channel.unary_unary(
                '/strmprivacy.api.purpose_mapping.v1.PurposeMappingService/ListPurposeMappings',
                request_serializer=strmprivacy_dot_api_dot_purpose__mapping_dot_v1_dot_purpose__mapping__v1__pb2.ListPurposeMappingsRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_purpose__mapping_dot_v1_dot_purpose__mapping__v1__pb2.ListPurposeMappingsResponse.FromString,
                )
        self.GetPurposeMapping = channel.unary_unary(
                '/strmprivacy.api.purpose_mapping.v1.PurposeMappingService/GetPurposeMapping',
                request_serializer=strmprivacy_dot_api_dot_purpose__mapping_dot_v1_dot_purpose__mapping__v1__pb2.GetPurposeMappingRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_purpose__mapping_dot_v1_dot_purpose__mapping__v1__pb2.GetPurposeMappingResponse.FromString,
                )
        self.CreatePurposeMapping = channel.unary_unary(
                '/strmprivacy.api.purpose_mapping.v1.PurposeMappingService/CreatePurposeMapping',
                request_serializer=strmprivacy_dot_api_dot_purpose__mapping_dot_v1_dot_purpose__mapping__v1__pb2.CreatePurposeMappingRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_purpose__mapping_dot_v1_dot_purpose__mapping__v1__pb2.CreatePurposeMappingResponse.FromString,
                )


class PurposeMappingServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ListPurposeMappings(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetPurposeMapping(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreatePurposeMapping(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_PurposeMappingServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ListPurposeMappings': grpc.unary_unary_rpc_method_handler(
                    servicer.ListPurposeMappings,
                    request_deserializer=strmprivacy_dot_api_dot_purpose__mapping_dot_v1_dot_purpose__mapping__v1__pb2.ListPurposeMappingsRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_purpose__mapping_dot_v1_dot_purpose__mapping__v1__pb2.ListPurposeMappingsResponse.SerializeToString,
            ),
            'GetPurposeMapping': grpc.unary_unary_rpc_method_handler(
                    servicer.GetPurposeMapping,
                    request_deserializer=strmprivacy_dot_api_dot_purpose__mapping_dot_v1_dot_purpose__mapping__v1__pb2.GetPurposeMappingRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_purpose__mapping_dot_v1_dot_purpose__mapping__v1__pb2.GetPurposeMappingResponse.SerializeToString,
            ),
            'CreatePurposeMapping': grpc.unary_unary_rpc_method_handler(
                    servicer.CreatePurposeMapping,
                    request_deserializer=strmprivacy_dot_api_dot_purpose__mapping_dot_v1_dot_purpose__mapping__v1__pb2.CreatePurposeMappingRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_purpose__mapping_dot_v1_dot_purpose__mapping__v1__pb2.CreatePurposeMappingResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'strmprivacy.api.purpose_mapping.v1.PurposeMappingService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class PurposeMappingService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ListPurposeMappings(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.purpose_mapping.v1.PurposeMappingService/ListPurposeMappings',
            strmprivacy_dot_api_dot_purpose__mapping_dot_v1_dot_purpose__mapping__v1__pb2.ListPurposeMappingsRequest.SerializeToString,
            strmprivacy_dot_api_dot_purpose__mapping_dot_v1_dot_purpose__mapping__v1__pb2.ListPurposeMappingsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetPurposeMapping(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.purpose_mapping.v1.PurposeMappingService/GetPurposeMapping',
            strmprivacy_dot_api_dot_purpose__mapping_dot_v1_dot_purpose__mapping__v1__pb2.GetPurposeMappingRequest.SerializeToString,
            strmprivacy_dot_api_dot_purpose__mapping_dot_v1_dot_purpose__mapping__v1__pb2.GetPurposeMappingResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreatePurposeMapping(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.purpose_mapping.v1.PurposeMappingService/CreatePurposeMapping',
            strmprivacy_dot_api_dot_purpose__mapping_dot_v1_dot_purpose__mapping__v1__pb2.CreatePurposeMappingRequest.SerializeToString,
            strmprivacy_dot_api_dot_purpose__mapping_dot_v1_dot_purpose__mapping__v1__pb2.CreatePurposeMappingResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from strmprivacy.api.credentials.v1 import credentials_v1_pb2 as strmprivacy_dot_api_dot_credentials_dot_v1_dot_credentials__v1__pb2


class CredentialsServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListCredentials = channel.unary_unary(
                '/strmprivacy.api.credentials.v1.CredentialsService/ListCredentials',
                request_serializer=strmprivacy_dot_api_dot_credentials_dot_v1_dot_credentials__v1__pb2.ListCredentialsRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_credentials_dot_v1_dot_credentials__v1__pb2.ListCredentialsResponse.FromString,
                )
        self.GetCredential = channel.unary_unary(
                '/strmprivacy.api.credentials.v1.CredentialsService/GetCredential',
                request_serializer=strmprivacy_dot_api_dot_credentials_dot_v1_dot_credentials__v1__pb2.GetCredentialRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_credentials_dot_v1_dot_credentials__v1__pb2.GetCredentialResponse.FromString,
                )
        self.CreateCredential = channel.unary_unary(
                '/strmprivacy.api.credentials.v1.CredentialsService/CreateCredential',
                request_serializer=strmprivacy_dot_api_dot_credentials_dot_v1_dot_credentials__v1__pb2.CreateCredentialRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_credentials_dot_v1_dot_credentials__v1__pb2.CreateCredentialResponse.FromString,
                )
        self.DeleteCredential = channel.unary_unary(
                '/strmprivacy.api.credentials.v1.CredentialsService/DeleteCredential',
                request_serializer=strmprivacy_dot_api_dot_credentials_dot_v1_dot_credentials__v1__pb2.DeleteCredentialRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_credentials_dot_v1_dot_credentials__v1__pb2.DeleteCredentialResponse.FromString,
                )


class CredentialsServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ListCredentials(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetCredential(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateCredential(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteCredential(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_CredentialsServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ListCredentials': grpc.unary_unary_rpc_method_handler(
                    servicer.ListCredentials,
                    request_deserializer=strmprivacy_dot_api_dot_credentials_dot_v1_dot_credentials__v1__pb2.ListCredentialsRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_credentials_dot_v1_dot_credentials__v1__pb2.ListCredentialsResponse.SerializeToString,
            ),
            'GetCredential': grpc.unary_unary_rpc_method_handler(
                    servicer.GetCredential,
                    request_deserializer=strmprivacy_dot_api_dot_credentials_dot_v1_dot_credentials__v1__pb2.GetCredentialRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_credentials_dot_v1_dot_credentials__v1__pb2.GetCredentialResponse.SerializeToString,
            ),
            'CreateCredential': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateCredential,
                    request_deserializer=strmprivacy_dot_api_dot_credentials_dot_v1_dot_credentials__v1__pb2.CreateCredentialRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_credentials_dot_v1_dot_credentials__v1__pb2.CreateCredentialResponse.SerializeToString,
            ),
            'DeleteCredential': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteCredential,
                    request_deserializer=strmprivacy_dot_api_dot_credentials_dot_v1_dot_credentials__v1__pb2.DeleteCredentialRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_credentials_dot_v1_dot_credentials__v1__pb2.DeleteCredentialResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'strmprivacy.api.credentials.v1.CredentialsService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class CredentialsService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ListCredentials(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.credentials.v1.CredentialsService/ListCredentials',
            strmprivacy_dot_api_dot_credentials_dot_v1_dot_credentials__v1__pb2.ListCredentialsRequest.SerializeToString,
            strmprivacy_dot_api_dot_credentials_dot_v1_dot_credentials__v1__pb2.ListCredentialsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetCredential(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.credentials.v1.CredentialsService/GetCredential',
            strmprivacy_dot_api_dot_credentials_dot_v1_dot_credentials__v1__pb2.GetCredentialRequest.SerializeToString,
            strmprivacy_dot_api_dot_credentials_dot_v1_dot_credentials__v1__pb2.GetCredentialResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateCredential(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.credentials.v1.CredentialsService/CreateCredential',
            strmprivacy_dot_api_dot_credentials_dot_v1_dot_credentials__v1__pb2.CreateCredentialRequest.SerializeToString,
            strmprivacy_dot_api_dot_credentials_dot_v1_dot_credentials__v1__pb2.CreateCredentialResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteCredential(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.credentials.v1.CredentialsService/DeleteCredential',
            strmprivacy_dot_api_dot_credentials_dot_v1_dot_credentials__v1__pb2.DeleteCredentialRequest.SerializeToString,
            strmprivacy_dot_api_dot_credentials_dot_v1_dot_credentials__v1__pb2.DeleteCredentialResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strmprivacy/api/key_streams/v1/key_streams.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from strmprivacy.api.entities.v1 import entities_v1_pb2 as strmprivacy_dot_api_dot_entities_dot_v1_dot_entities__v1__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n0strmprivacy/api/key_streams/v1/key_streams.proto\x12\x1estrmprivacy.api.key_streams.v1\x1a\x1fgoogle/api/field_behavior.proto\x1a-strmprivacy/api/entities/v1/entities_v1.proto\x1a\x17validate/validate.proto\"n\n\x15ListKeyStreamsRequest\x12,\n\nbilling_id\x18\x01 \x01(\tB\r\x18\x01\xfa\x42\x08r\x06\x98\x01\x00\xd0\x01\x01R\tbillingId\x12\'\n\nproject_id\x18\x02 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01R\tprojectId\"a\n\x16ListKeyStreamsResponse\x12G\n\x0bkey_streams\x18\x01 \x03(\x0b\x32&.strmprivacy.api.entities.v1.KeyStreamR\nkeyStreams\"\\\n\x13GetKeyStreamRequest\x12\x45\n\x03ref\x18\x01 \x01(\x0b\x32).strmprivacy.api.entities.v1.KeyStreamRefB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\x03ref\"b\n\x14GetKeyStreamResponse\x12J\n\nkey_stream\x18\x01 \x01(\x0b\x32&.strmprivacy.api.entities.v1.KeyStreamB\x03\xe0\x41\x02R\tkeyStream2\x8f\x02\n\x11KeyStreamsService\x12\x7f\n\x0eListKeyStreams\x12\x35.strmprivacy.api.key_streams.v1.ListKeyStreamsRequest\x1a\x36.strmprivacy.api.key_streams.v1.ListKeyStreamsResponse\x12y\n\x0cGetKeyStream\x12\x33.strmprivacy.api.key_streams.v1.GetKeyStreamRequest\x1a\x34.strmprivacy.api.key_streams.v1.GetKeyStreamResponseBr\n!io.strmprivacy.api.key_streams.v1P\x01ZKgithub.com/strmprivacy/api-definitions-go/v2/api/key_streams/v1;key_streamsb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'strmprivacy.api.key_streams.v1.key_streams_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n!io.strmprivacy.api.key_streams.v1P\001ZKgithub.com/strmprivacy/api-definitions-go/v2/api/key_streams/v1;key_streams'
  _LISTKEYSTREAMSREQUEST.fields_by_name['billing_id']._options = None
  _LISTKEYSTREAMSREQUEST.fields_by_name['billing_id']._serialized_options = b'\030\001\372B\010r\006\230\001\000\320\001\001'
  _LISTKEYSTREAMSREQUEST.fields_by_name['project_id']._options = None
  _LISTKEYSTREAMSREQUEST.fields_by_name['project_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _GETKEYSTREAMREQUEST.fields_by_name['ref']._options = None
  _GETKEYSTREAMREQUEST.fields_by_name['ref']._serialized_options = b'\372B\005\212\001\002\020\001'
  _GETKEYSTREAMRESPONSE.fields_by_name['key_stream']._options = None
  _GETKEYSTREAMRESPONSE.fields_by_name['key_stream']._serialized_options = b'\340A\002'
  _LISTKEYSTREAMSREQUEST._serialized_start=189
  _LISTKEYSTREAMSREQUEST._serialized_end=299
  _LISTKEYSTREAMSRESPONSE._serialized_start=301
  _LISTKEYSTREAMSRESPONSE._serialized_end=398
  _GETKEYSTREAMREQUEST._serialized_start=400
  _GETKEYSTREAMREQUEST._serialized_end=492
  _GETKEYSTREAMRESPONSE._serialized_start=494
  _GETKEYSTREAMRESPONSE._serialized_end=592
  _KEYSTREAMSSERVICE._serialized_start=595
  _KEYSTREAMSSERVICE._serialized_end=866
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strmprivacy/api/event_contracts/v1/event_contracts_v1.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from strmprivacy.api.entities.v1 import entities_v1_pb2 as strmprivacy_dot_api_dot_entities_dot_v1_dot_entities__v1__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n;strmprivacy/api/event_contracts/v1/event_contracts_v1.proto\x12\"strmprivacy.api.event_contracts.v1\x1a\x1fgoogle/api/field_behavior.proto\x1a google/protobuf/field_mask.proto\x1a-strmprivacy/api/entities/v1/entities_v1.proto\"\xc0\x03\n\x19ListEventContractsRequest\x12!\n\nbilling_id\x18\x01 \x01(\tB\x02\x18\x01R\tbillingId\x12\x1b\n\x06\x66ilter\x18\x02 \x01(\tB\x03\xe0\x41\x01R\x06\x66ilter\x12\x1b\n\x06handle\x18\x03 \x01(\tB\x03\xe0\x41\x01R\x06handle\x12\x17\n\x04name\x18\x04 \x01(\tB\x03\xe0\x41\x01R\x04name\x12\\\n\x0epublic_private\x18\x05 \x01(\x0e\x32\x30.strmprivacy.api.entities.v1.FilterPublicPrivateB\x03\xe0\x41\x01R\rpublicPrivate\x12J\n\nschema_ref\x18\x06 \x01(\x0b\x32&.strmprivacy.api.entities.v1.SchemaRefB\x03\xe0\x41\x01R\tschemaRef\x12?\n\x06labels\x18\x07 \x03(\x0b\x32\".strmprivacy.api.entities.v1.LabelB\x03\xe0\x41\x01R\x06labels\x12\x1d\n\x07\x64omains\x18\x08 \x03(\tB\x03\xe0\x41\x01R\x07\x64omains\x12#\n\nindustries\x18\t \x03(\tB\x03\xe0\x41\x01R\nindustries\"q\n\x1aListEventContractsResponse\x12S\n\x0f\x65vent_contracts\x18\x01 \x03(\x0b\x32*.strmprivacy.api.entities.v1.EventContractR\x0e\x65ventContracts\"}\n\x17GetEventContractRequest\x12!\n\nbilling_id\x18\x01 \x01(\tB\x02\x18\x01R\tbillingId\x12?\n\x03ref\x18\x02 \x01(\x0b\x32-.strmprivacy.api.entities.v1.EventContractRefR\x03ref\"\x8e\x01\n\x18GetEventContractResponse\x12Q\n\x0e\x65vent_contract\x18\x01 \x01(\x0b\x32*.strmprivacy.api.entities.v1.EventContractR\reventContract\x12\x1f\n\x08\x63hecksum\x18\x02 \x01(\tB\x03\xe0\x41\x02R\x08\x63hecksum\"\xb1\x01\n\x1a\x43reateEventContractRequest\x12!\n\nbilling_id\x18\x01 \x01(\tB\x02\x18\x01R\tbillingId\x12Q\n\x0e\x65vent_contract\x18\x02 \x01(\x0b\x32*.strmprivacy.api.entities.v1.EventContractR\reventContract\x12\x1d\n\nproject_id\x18\x03 \x01(\tR\tprojectId\"\x91\x01\n\x1b\x43reateEventContractResponse\x12Q\n\x0e\x65vent_contract\x18\x01 \x01(\x0b\x32*.strmprivacy.api.entities.v1.EventContractR\reventContract\x12\x1f\n\x08\x63hecksum\x18\x02 \x01(\tB\x03\xe0\x41\x03R\x08\x63hecksum\"\x9e\x02\n\x1aUpdateEventContractRequest\x12!\n\nbilling_id\x18\x01 \x01(\tB\x02\x18\x01R\tbillingId\x12V\n\x0e\x65vent_contract\x18\x02 \x01(\x0b\x32*.strmprivacy.api.entities.v1.EventContractB\x03\xe0\x41\x02R\reventContract\x12\x1f\n\x08\x63hecksum\x18\x03 \x01(\tB\x03\xe0\x41\x02R\x08\x63hecksum\x12@\n\x0bupdate_mask\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x03\xe0\x41\x02R\nupdateMask\x12\"\n\nproject_id\x18\x05 \x01(\tB\x03\xe0\x41\x02R\tprojectId\"\x91\x01\n\x1bUpdateEventContractResponse\x12Q\n\x0e\x65vent_contract\x18\x01 \x01(\x0b\x32*.strmprivacy.api.entities.v1.EventContractR\reventContract\x12\x1f\n\x08\x63hecksum\x18\x02 \x01(\tB\x03\xe0\x41\x03R\x08\x63hecksum\"\xc7\x01\n\x1c\x41\x63tivateEventContractRequest\x12!\n\nbilling_id\x18\x01 \x01(\tB\x02\x18\x01R\tbillingId\x12`\n\x12\x65vent_contract_ref\x18\x02 \x01(\x0b\x32-.strmprivacy.api.entities.v1.EventContractRefB\x03\xe0\x41\x02R\x10\x65ventContractRef\x12\"\n\nproject_id\x18\x03 \x01(\tB\x03\xe0\x41\x02R\tprojectId\"\x1f\n\x1d\x41\x63tivateEventContractResponse\"\xc5\x01\n\x1a\x44\x65leteEventContractRequest\x12!\n\nbilling_id\x18\x01 \x01(\tB\x02\x18\x01R\tbillingId\x12`\n\x12\x65vent_contract_ref\x18\x02 \x01(\x0b\x32-.strmprivacy.api.entities.v1.EventContractRefB\x03\xe0\x41\x02R\x10\x65ventContractRef\x12\"\n\nproject_id\x18\x03 \x01(\tB\x03\xe0\x41\x02R\tprojectId\"\x1d\n\x1b\x44\x65leteEventContractResponse\"\xc6\x01\n\x1b\x41rchiveEventContractRequest\x12!\n\nbilling_id\x18\x01 \x01(\tB\x02\x18\x01R\tbillingId\x12`\n\x12\x65vent_contract_ref\x18\x02 \x01(\x0b\x32-.strmprivacy.api.entities.v1.EventContractRefB\x03\xe0\x41\x02R\x10\x65ventContractRef\x12\"\n\nproject_id\x18\x03 \x01(\tB\x03\xe0\x41\x02R\tprojectId\"\x1e\n\x1c\x41rchiveEventContractResponse\"\xb4\x01\n\x1bValidateMaskedFieldsRequest\x12!\n\nbilling_id\x18\x01 \x01(\tB\x02\x18\x01R\tbillingId\x12N\n\rmasked_fields\x18\x02 \x01(\x0b\x32).strmprivacy.api.entities.v1.MaskedFieldsR\x0cmaskedFields\x12\"\n\nproject_id\x18\x03 \x01(\tB\x03\xe0\x41\x02R\tprojectId\"\xd6\x03\n\x1cValidateMaskedFieldsResponse\x12^\n\x06\x65rrors\x18\x01 \x03(\x0b\x32\x46.strmprivacy.api.event_contracts.v1.ValidateMaskedFieldsResponse.ErrorR\x06\x65rrors\x1a\xd5\x02\n\x05\x45rror\x12[\n\x12\x65vent_contract_ref\x18\x01 \x01(\x0b\x32-.strmprivacy.api.entities.v1.EventContractRefR\x10\x65ventContractRef\x12\x18\n\x07message\x18\x02 \x01(\tR\x07message\x12i\n\x06\x65rrors\x18\x03 \x03(\x0b\x32Q.strmprivacy.api.event_contracts.v1.ValidateMaskedFieldsResponse.Error.FieldErrorR\x06\x65rrors\x1aj\n\nFieldError\x12#\n\rfield_pattern\x18\x01 \x01(\tR\x0c\x66ieldPattern\x12\x1d\n\nfield_type\x18\x02 \x01(\tR\tfieldType\x12\x18\n\x07message\x18\x03 \x01(\tR\x07message\"c\n GetEventContractAndSchemaRequest\x12?\n\x03ref\x18\x01 \x01(\x0b\x32-.strmprivacy.api.entities.v1.EventContractRefR\x03ref\"\xd6\x01\n!GetEventContractAndSchemaResponse\x12Q\n\x0e\x65vent_contract\x18\x01 \x01(\x0b\x32*.strmprivacy.api.entities.v1.EventContractR\reventContract\x12;\n\x06schema\x18\x02 \x01(\x0b\x32#.strmprivacy.api.entities.v1.SchemaR\x06schema\x12!\n\x0c\x63onfluent_id\x18\x03 \x01(\x05R\x0b\x63onfluentId2\x8a\x0b\n\x15\x45ventContractsService\x12\x93\x01\n\x12ListEventContracts\x12=.strmprivacy.api.event_contracts.v1.ListEventContractsRequest\x1a>.strmprivacy.api.event_contracts.v1.ListEventContractsResponse\x12\x8d\x01\n\x10GetEventContract\x12;.strmprivacy.api.event_contracts.v1.GetEventContractRequest\x1a<.strmprivacy.api.event_contracts.v1.GetEventContractResponse\x12\x96\x01\n\x13\x43reateEventContract\x12>.strmprivacy.api.event_contracts.v1.CreateEventContractRequest\x1a?.strmprivacy.api.event_contracts.v1.CreateEventContractResponse\x12\x96\x01\n\x13UpdateEventContract\x12>.strmprivacy.api.event_contracts.v1.UpdateEventContractRequest\x1a?.strmprivacy.api.event_contracts.v1.UpdateEventContractResponse\x12\x9c\x01\n\x15\x41\x63tivateEventContract\x12@.strmprivacy.api.event_contracts.v1.ActivateEventContractRequest\x1a\x41.strmprivacy.api.event_contracts.v1.ActivateEventContractResponse\x12\x96\x01\n\x13\x44\x65leteEventContract\x12>.strmprivacy.api.event_contracts.v1.DeleteEventContractRequest\x1a?.strmprivacy.api.event_contracts.v1.DeleteEventContractResponse\x12\x99\x01\n\x14\x41rchiveEventContract\x12?.strmprivacy.api.event_contracts.v1.ArchiveEventContractRequest\x1a@.strmprivacy.api.event_contracts.v1.ArchiveEventContractResponse\x12\x99\x01\n\x14ValidateMaskedFields\x12?.strmprivacy.api.event_contracts.v1.ValidateMaskedFieldsRequest\x1a@.strmprivacy.api.event_contracts.v1.ValidateMaskedFieldsResponse\x12\xa8\x01\n\x19GetEventContractAndSchema\x12\x44.strmprivacy.api.event_contracts.v1.GetEventContractAndSchemaRequest\x1a\x45.strmprivacy.api.event_contracts.v1.GetEventContractAndSchemaResponseB~\n%io.strmprivacy.api.event_contracts.v1P\x01ZSgithub.com/strmprivacy/api-definitions-go/v2/api/event_contracts/v1;event_contractsb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'strmprivacy.api.event_contracts.v1.event_contracts_v1_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n%io.strmprivacy.api.event_contracts.v1P\001ZSgithub.com/strmprivacy/api-definitions-go/v2/api/event_contracts/v1;event_contracts'
  _LISTEVENTCONTRACTSREQUEST.fields_by_name['billing_id']._options = None
  _LISTEVENTCONTRACTSREQUEST.fields_by_name['billing_id']._serialized_options = b'\030\001'
  _LISTEVENTCONTRACTSREQUEST.fields_by_name['filter']._options = None
  _LISTEVENTCONTRACTSREQUEST.fields_by_name['filter']._serialized_options = b'\340A\001'
  _LISTEVENTCONTRACTSREQUEST.fields_by_name['handle']._options = None
  _LISTEVENTCONTRACTSREQUEST.fields_by_name['handle']._serialized_options = b'\340A\001'
  _LISTEVENTCONTRACTSREQUEST.fields_by_name['name']._options = None
  _LISTEVENTCONTRACTSREQUEST.fields_by_name['name']._serialized_options = b'\340A\001'
  _LISTEVENTCONTRACTSREQUEST.fields_by_name['public_private']._options = None
  _LISTEVENTCONTRACTSREQUEST.fields_by_name['public_private']._serialized_options = b'\340A\001'
  _LISTEVENTCONTRACTSREQUEST.fields_by_name['schema_ref']._options = None
  _LISTEVENTCONTRACTSREQUEST.fields_by_name['schema_ref']._serialized_options = b'\340A\001'
  _LISTEVENTCONTRACTSREQUEST.fields_by_name['labels']._options = None
  _LISTEVENTCONTRACTSREQUEST.fields_by_name['labels']._serialized_options = b'\340A\001'
  _LISTEVENTCONTRACTSREQUEST.fields_by_name['domains']._options = None
  _LISTEVENTCONTRACTSREQUEST.fields_by_name['domains']._serialized_options = b'\340A\001'
  _LISTEVENTCONTRACTSREQUEST.fields_by_name['industries']._options = None
  _LISTEVENTCONTRACTSREQUEST.fields_by_name['industries']._serialized_options = b'\340A\001'
  _GETEVENTCONTRACTREQUEST.fields_by_name['billing_id']._options = None
  _GETEVENTCONTRACTREQUEST.fields_by_name['billing_id']._serialized_options = b'\030\001'
  _GETEVENTCONTRACTRESPONSE.fields_by_name['checksum']._options = None
  _GETEVENTCONTRACTRESPONSE.fields_by_name['checksum']._serialized_options = b'\340A\002'
  _CREATEEVENTCONTRACTREQUEST.fields_by_name['billing_id']._options = None
  _CREATEEVENTCONTRACTREQUEST.fields_by_name['billing_id']._serialized_options = b'\030\001'
  _CREATEEVENTCONTRACTRESPONSE.fields_by_name['checksum']._options = None
  _CREATEEVENTCONTRACTRESPONSE.fields_by_name['checksum']._serialized_options = b'\340A\003'
  _UPDATEEVENTCONTRACTREQUEST.fields_by_name['billing_id']._options = None
  _UPDATEEVENTCONTRACTREQUEST.fields_by_name['billing_id']._serialized_options = b'\030\001'
  _UPDATEEVENTCONTRACTREQUEST.fields_by_name['event_contract']._options = None
  _UPDATEEVENTCONTRACTREQUEST.fields_by_name['event_contract']._serialized_options = b'\340A\002'
  _UPDATEEVENTCONTRACTREQUEST.fields_by_name['checksum']._options = None
  _UPDATEEVENTCONTRACTREQUEST.fields_by_name['checksum']._serialized_options = b'\340A\002'
  _UPDATEEVENTCONTRACTREQUEST.fields_by_name['update_mask']._options = None
  _UPDATEEVENTCONTRACTREQUEST.fields_by_name['update_mask']._serialized_options = b'\340A\002'
  _UPDATEEVENTCONTRACTREQUEST.fields_by_name['project_id']._options = None
  _UPDATEEVENTCONTRACTREQUEST.fields_by_name['project_id']._serialized_options = b'\340A\002'
  _UPDATEEVENTCONTRACTRESPONSE.fields_by_name['checksum']._options = None
  _UPDATEEVENTCONTRACTRESPONSE.fields_by_name['checksum']._serialized_options = b'\340A\003'
  _ACTIVATEEVENTCONTRACTREQUEST.fields_by_name['billing_id']._options = None
  _ACTIVATEEVENTCONTRACTREQUEST.fields_by_name['billing_id']._serialized_options = b'\030\001'
  _ACTIVATEEVENTCONTRACTREQUEST.fields_by_name['event_contract_ref']._options = None
  _ACTIVATEEVENTCONTRACTREQUEST.fields_by_name['event_contract_ref']._serialized_options = b'\340A\002'
  _ACTIVATEEVENTCONTRACTREQUEST.fields_by_name['project_id']._options = None
  _ACTIVATEEVENTCONTRACTREQUEST.fields_by_name['project_id']._serialized_options = b'\340A\002'
  _DELETEEVENTCONTRACTREQUEST.fields_by_name['billing_id']._options = None
  _DELETEEVENTCONTRACTREQUEST.fields_by_name['billing_id']._serialized_options = b'\030\001'
  _DELETEEVENTCONTRACTREQUEST.fields_by_name['event_contract_ref']._options = None
  _DELETEEVENTCONTRACTREQUEST.fields_by_name['event_contract_ref']._serialized_options = b'\340A\002'
  _DELETEEVENTCONTRACTREQUEST.fields_by_name['project_id']._options = None
  _DELETEEVENTCONTRACTREQUEST.fields_by_name['project_id']._serialized_options = b'\340A\002'
  _ARCHIVEEVENTCONTRACTREQUEST.fields_by_name['billing_id']._options = None
  _ARCHIVEEVENTCONTRACTREQUEST.fields_by_name['billing_id']._serialized_options = b'\030\001'
  _ARCHIVEEVENTCONTRACTREQUEST.fields_by_name['event_contract_ref']._options = None
  _ARCHIVEEVENTCONTRACTREQUEST.fields_by_name['event_contract_ref']._serialized_options = b'\340A\002'
  _ARCHIVEEVENTCONTRACTREQUEST.fields_by_name['project_id']._options = None
  _ARCHIVEEVENTCONTRACTREQUEST.fields_by_name['project_id']._serialized_options = b'\340A\002'
  _VALIDATEMASKEDFIELDSREQUEST.fields_by_name['billing_id']._options = None
  _VALIDATEMASKEDFIELDSREQUEST.fields_by_name['billing_id']._serialized_options = b'\030\001'
  _VALIDATEMASKEDFIELDSREQUEST.fields_by_name['project_id']._options = None
  _VALIDATEMASKEDFIELDSREQUEST.fields_by_name['project_id']._serialized_options = b'\340A\002'
  _LISTEVENTCONTRACTSREQUEST._serialized_start=214
  _LISTEVENTCONTRACTSREQUEST._serialized_end=662
  _LISTEVENTCONTRACTSRESPONSE._serialized_start=664
  _LISTEVENTCONTRACTSRESPONSE._serialized_end=777
  _GETEVENTCONTRACTREQUEST._serialized_start=779
  _GETEVENTCONTRACTREQUEST._serialized_end=904
  _GETEVENTCONTRACTRESPONSE._serialized_start=907
  _GETEVENTCONTRACTRESPONSE._serialized_end=1049
  _CREATEEVENTCONTRACTREQUEST._serialized_start=1052
  _CREATEEVENTCONTRACTREQUEST._serialized_end=1229
  _CREATEEVENTCONTRACTRESPONSE._serialized_start=1232
  _CREATEEVENTCONTRACTRESPONSE._serialized_end=1377
  _UPDATEEVENTCONTRACTREQUEST._serialized_start=1380
  _UPDATEEVENTCONTRACTREQUEST._serialized_end=1666
  _UPDATEEVENTCONTRACTRESPONSE._serialized_start=1669
  _UPDATEEVENTCONTRACTRESPONSE._serialized_end=1814
  _ACTIVATEEVENTCONTRACTREQUEST._serialized_start=1817
  _ACTIVATEEVENTCONTRACTREQUEST._serialized_end=2016
  _ACTIVATEEVENTCONTRACTRESPONSE._serialized_start=2018
  _ACTIVATEEVENTCONTRACTRESPONSE._serialized_end=2049
  _DELETEEVENTCONTRACTREQUEST._serialized_start=2052
  _DELETEEVENTCONTRACTREQUEST._serialized_end=2249
  _DELETEEVENTCONTRACTRESPONSE._serialized_start=2251
  _DELETEEVENTCONTRACTRESPONSE._serialized_end=2280
  _ARCHIVEEVENTCONTRACTREQUEST._serialized_start=2283
  _ARCHIVEEVENTCONTRACTREQUEST._serialized_end=2481
  _ARCHIVEEVENTCONTRACTRESPONSE._serialized_start=2483
  _ARCHIVEEVENTCONTRACTRESPONSE._serialized_end=2513
  _VALIDATEMASKEDFIELDSREQUEST._serialized_start=2516
  _VALIDATEMASKEDFIELDSREQUEST._serialized_end=2696
  _VALIDATEMASKEDFIELDSRESPONSE._serialized_start=2699
  _VALIDATEMASKEDFIELDSRESPONSE._serialized_end=3169
  _VALIDATEMASKEDFIELDSRESPONSE_ERROR._serialized_start=2828
  _VALIDATEMASKEDFIELDSRESPONSE_ERROR._serialized_end=3169
  _VALIDATEMASKEDFIELDSRESPONSE_ERROR_FIELDERROR._serialized_start=3063
  _VALIDATEMASKEDFIELDSRESPONSE_ERROR_FIELDERROR._serialized_end=3169
  _GETEVENTCONTRACTANDSCHEMAREQUEST._serialized_start=3171
  _GETEVENTCONTRACTANDSCHEMAREQUEST._serialized_end=3270
  _GETEVENTCONTRACTANDSCHEMARESPONSE._serialized_start=3273
  _GETEVENTCONTRACTANDSCHEMARESPONSE._serialized_end=3487
  _EVENTCONTRACTSSERVICE._serialized_start=3490
  _EVENTCONTRACTSSERVICE._serialized_end=4908
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strmprivacy/api/kafka_clusters/v1/kafka_clusters_v1.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from strmprivacy.api.entities.v1 import entities_v1_pb2 as strmprivacy_dot_api_dot_entities_dot_v1_dot_entities__v1__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n9strmprivacy/api/kafka_clusters/v1/kafka_clusters_v1.proto\x12!strmprivacy.api.kafka_clusters.v1\x1a-strmprivacy/api/entities/v1/entities_v1.proto\x1a\x17validate/validate.proto\"t\n\x18ListKafkaClustersRequest\x12,\n\nbilling_id\x18\x01 \x01(\tB\r\x18\x01\xfa\x42\x08r\x06\x98\x01\x00\xd0\x01\x01R\tbillingId\x12*\n\nproject_id\x18\x02 \x01(\tB\x0b\xfa\x42\x08r\x06\xd0\x01\x01\xb0\x01\x01R\tprojectId\"m\n\x19ListKafkaClustersResponse\x12P\n\x0ekafka_clusters\x18\x01 \x03(\x0b\x32).strmprivacy.api.entities.v1.KafkaClusterR\rkafkaClusters\"\xbf\x01\n\x19\x44\x65leteKafkaClusterRequest\x12,\n\nbilling_id\x18\x01 \x01(\tB\r\x18\x01\xfa\x42\x08r\x06\x98\x01\x00\xd0\x01\x01R\tbillingId\x12H\n\x03ref\x18\x02 \x01(\x0b\x32,.strmprivacy.api.entities.v1.KafkaClusterRefB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\x03ref\x12*\n\nproject_id\x18\x03 \x01(\tB\x0b\xfa\x42\x08r\x06\xd0\x01\x01\xb0\x01\x01R\tprojectId\"\x1c\n\x1a\x44\x65leteKafkaClusterResponse\"k\n\x19\x43reateKafkaClusterRequest\x12N\n\rkafka_cluster\x18\x01 \x01(\x0b\x32).strmprivacy.api.entities.v1.KafkaClusterR\x0ckafkaCluster\"l\n\x1a\x43reateKafkaClusterResponse\x12N\n\rkafka_cluster\x18\x01 \x01(\x0b\x32).strmprivacy.api.entities.v1.KafkaClusterR\x0ckafkaCluster\"\xbc\x01\n\x16GetKafkaClusterRequest\x12,\n\nbilling_id\x18\x01 \x01(\tB\r\x18\x01\xfa\x42\x08r\x06\x98\x01\x00\xd0\x01\x01R\tbillingId\x12H\n\x03ref\x18\x02 \x01(\x0b\x32,.strmprivacy.api.entities.v1.KafkaClusterRefB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\x03ref\x12*\n\nproject_id\x18\x03 \x01(\tB\x0b\xfa\x42\x08r\x06\xd0\x01\x01\xb0\x01\x01R\tprojectId\"i\n\x17GetKafkaClusterResponse\x12N\n\rkafka_cluster\x18\x01 \x01(\x0b\x32).strmprivacy.api.entities.v1.KafkaClusterR\x0ckafkaCluster2\xda\x04\n\x14KafkaClustersService\x12\x8e\x01\n\x11ListKafkaClusters\x12;.strmprivacy.api.kafka_clusters.v1.ListKafkaClustersRequest\x1a<.strmprivacy.api.kafka_clusters.v1.ListKafkaClustersResponse\x12\x88\x01\n\x0fGetKafkaCluster\x12\x39.strmprivacy.api.kafka_clusters.v1.GetKafkaClusterRequest\x1a:.strmprivacy.api.kafka_clusters.v1.GetKafkaClusterResponse\x12\x91\x01\n\x12\x44\x65leteKafkaCluster\x12<.strmprivacy.api.kafka_clusters.v1.DeleteKafkaClusterRequest\x1a=.strmprivacy.api.kafka_clusters.v1.DeleteKafkaClusterResponse\x12\x91\x01\n\x12\x43reateKafkaCluster\x12<.strmprivacy.api.kafka_clusters.v1.CreateKafkaClusterRequest\x1a=.strmprivacy.api.kafka_clusters.v1.CreateKafkaClusterResponseB{\n$io.strmprivacy.api.kafka_clusters.v1P\x01ZQgithub.com/strmprivacy/api-definitions-go/v2/api/kafka_clusters/v1;kafka_clustersb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'strmprivacy.api.kafka_clusters.v1.kafka_clusters_v1_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n$io.strmprivacy.api.kafka_clusters.v1P\001ZQgithub.com/strmprivacy/api-definitions-go/v2/api/kafka_clusters/v1;kafka_clusters'
  _LISTKAFKACLUSTERSREQUEST.fields_by_name['billing_id']._options = None
  _LISTKAFKACLUSTERSREQUEST.fields_by_name['billing_id']._serialized_options = b'\030\001\372B\010r\006\230\001\000\320\001\001'
  _LISTKAFKACLUSTERSREQUEST.fields_by_name['project_id']._options = None
  _LISTKAFKACLUSTERSREQUEST.fields_by_name['project_id']._serialized_options = b'\372B\010r\006\320\001\001\260\001\001'
  _DELETEKAFKACLUSTERREQUEST.fields_by_name['billing_id']._options = None
  _DELETEKAFKACLUSTERREQUEST.fields_by_name['billing_id']._serialized_options = b'\030\001\372B\010r\006\230\001\000\320\001\001'
  _DELETEKAFKACLUSTERREQUEST.fields_by_name['ref']._options = None
  _DELETEKAFKACLUSTERREQUEST.fields_by_name['ref']._serialized_options = b'\372B\005\212\001\002\020\001'
  _DELETEKAFKACLUSTERREQUEST.fields_by_name['project_id']._options = None
  _DELETEKAFKACLUSTERREQUEST.fields_by_name['project_id']._serialized_options = b'\372B\010r\006\320\001\001\260\001\001'
  _GETKAFKACLUSTERREQUEST.fields_by_name['billing_id']._options = None
  _GETKAFKACLUSTERREQUEST.fields_by_name['billing_id']._serialized_options = b'\030\001\372B\010r\006\230\001\000\320\001\001'
  _GETKAFKACLUSTERREQUEST.fields_by_name['ref']._options = None
  _GETKAFKACLUSTERREQUEST.fields_by_name['ref']._serialized_options = b'\372B\005\212\001\002\020\001'
  _GETKAFKACLUSTERREQUEST.fields_by_name['project_id']._options = None
  _GETKAFKACLUSTERREQUEST.fields_by_name['project_id']._serialized_options = b'\372B\010r\006\320\001\001\260\001\001'
  _LISTKAFKACLUSTERSREQUEST._serialized_start=168
  _LISTKAFKACLUSTERSREQUEST._serialized_end=284
  _LISTKAFKACLUSTERSRESPONSE._serialized_start=286
  _LISTKAFKACLUSTERSRESPONSE._serialized_end=395
  _DELETEKAFKACLUSTERREQUEST._serialized_start=398
  _DELETEKAFKACLUSTERREQUEST._serialized_end=589
  _DELETEKAFKACLUSTERRESPONSE._serialized_start=591
  _DELETEKAFKACLUSTERRESPONSE._serialized_end=619
  _CREATEKAFKACLUSTERREQUEST._serialized_start=621
  _CREATEKAFKACLUSTERREQUEST._serialized_end=728
  _CREATEKAFKACLUSTERRESPONSE._serialized_start=730
  _CREATEKAFKACLUSTERRESPONSE._serialized_end=838
  _GETKAFKACLUSTERREQUEST._serialized_start=841
  _GETKAFKACLUSTERREQUEST._serialized_end=1029
  _GETKAFKACLUSTERRESPONSE._serialized_start=1031
  _GETKAFKACLUSTERRESPONSE._serialized_end=1136
  _KAFKACLUSTERSSERVICE._serialized_start=1139
  _KAFKACLUSTERSSERVICE._serialized_end=1741
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strmprivacy/api/data_connectors/v1/data_connectors_v1.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from strmprivacy.api.entities.v1 import entities_v1_pb2 as strmprivacy_dot_api_dot_entities_dot_v1_dot_entities__v1__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n;strmprivacy/api/data_connectors/v1/data_connectors_v1.proto\x12\"strmprivacy.api.data_connectors.v1\x1a\x1fgoogle/api/field_behavior.proto\x1a-strmprivacy/api/entities/v1/entities_v1.proto\x1a\x17validate/validate.proto\"\xc1\x01\n\x19ListDataConnectorsRequest\x12,\n\nbilling_id\x18\x01 \x01(\tB\r\x18\x01\xfa\x42\x08r\x06\x98\x01\x00\xd0\x01\x01R\tbillingId\x12\x1c\n\trecursive\x18\x02 \x01(\x08R\trecursive\x12/\n\x13include_credentials\x18\x03 \x01(\x08R\x12includeCredentials\x12\'\n\nproject_id\x18\x04 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01R\tprojectId\"q\n\x1aListDataConnectorsResponse\x12S\n\x0f\x64\x61ta_connectors\x18\x01 \x03(\x0b\x32*.strmprivacy.api.entities.v1.DataConnectorR\x0e\x64\x61taConnectors\"\x85\x01\n\x1a\x44\x65leteDataConnectorRequest\x12I\n\x03ref\x18\x01 \x01(\x0b\x32-.strmprivacy.api.entities.v1.DataConnectorRefB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\x03ref\x12\x1c\n\trecursive\x18\x02 \x01(\x08R\trecursive\"\x1d\n\x1b\x44\x65leteDataConnectorResponse\"y\n\x1a\x43reateDataConnectorRequest\x12[\n\x0e\x64\x61ta_connector\x18\x01 \x01(\x0b\x32*.strmprivacy.api.entities.v1.DataConnectorB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\rdataConnector\"u\n\x1b\x43reateDataConnectorResponse\x12V\n\x0e\x64\x61ta_connector\x18\x01 \x01(\x0b\x32*.strmprivacy.api.entities.v1.DataConnectorB\x03\xe0\x41\x02R\rdataConnector\"\xb3\x01\n\x17GetDataConnectorRequest\x12I\n\x03ref\x18\x01 \x01(\x0b\x32-.strmprivacy.api.entities.v1.DataConnectorRefB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\x03ref\x12\x1c\n\trecursive\x18\x02 \x01(\x08R\trecursive\x12/\n\x13include_credentials\x18\x03 \x01(\x08R\x12includeCredentials\"m\n\x18GetDataConnectorResponse\x12Q\n\x0e\x64\x61ta_connector\x18\x01 \x01(\x0b\x32*.strmprivacy.api.entities.v1.DataConnectorR\rdataConnector2\xef\x04\n\x15\x44\x61taConnectorsService\x12\x93\x01\n\x12ListDataConnectors\x12=.strmprivacy.api.data_connectors.v1.ListDataConnectorsRequest\x1a>.strmprivacy.api.data_connectors.v1.ListDataConnectorsResponse\x12\x8d\x01\n\x10GetDataConnector\x12;.strmprivacy.api.data_connectors.v1.GetDataConnectorRequest\x1a<.strmprivacy.api.data_connectors.v1.GetDataConnectorResponse\x12\x96\x01\n\x13\x44\x65leteDataConnector\x12>.strmprivacy.api.data_connectors.v1.DeleteDataConnectorRequest\x1a?.strmprivacy.api.data_connectors.v1.DeleteDataConnectorResponse\x12\x96\x01\n\x13\x43reateDataConnector\x12>.strmprivacy.api.data_connectors.v1.CreateDataConnectorRequest\x1a?.strmprivacy.api.data_connectors.v1.CreateDataConnectorResponseB~\n%io.strmprivacy.api.data_connectors.v1P\x01ZSgithub.com/strmprivacy/api-definitions-go/v2/api/data_connectors/v1;data_connectorsb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'strmprivacy.api.data_connectors.v1.data_connectors_v1_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n%io.strmprivacy.api.data_connectors.v1P\001ZSgithub.com/strmprivacy/api-definitions-go/v2/api/data_connectors/v1;data_connectors'
  _LISTDATACONNECTORSREQUEST.fields_by_name['billing_id']._options = None
  _LISTDATACONNECTORSREQUEST.fields_by_name['billing_id']._serialized_options = b'\030\001\372B\010r\006\230\001\000\320\001\001'
  _LISTDATACONNECTORSREQUEST.fields_by_name['project_id']._options = None
  _LISTDATACONNECTORSREQUEST.fields_by_name['project_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _DELETEDATACONNECTORREQUEST.fields_by_name['ref']._options = None
  _DELETEDATACONNECTORREQUEST.fields_by_name['ref']._serialized_options = b'\372B\005\212\001\002\020\001'
  _CREATEDATACONNECTORREQUEST.fields_by_name['data_connector']._options = None
  _CREATEDATACONNECTORREQUEST.fields_by_name['data_connector']._serialized_options = b'\372B\005\212\001\002\020\001'
  _CREATEDATACONNECTORRESPONSE.fields_by_name['data_connector']._options = None
  _CREATEDATACONNECTORRESPONSE.fields_by_name['data_connector']._serialized_options = b'\340A\002'
  _GETDATACONNECTORREQUEST.fields_by_name['ref']._options = None
  _GETDATACONNECTORREQUEST.fields_by_name['ref']._serialized_options = b'\372B\005\212\001\002\020\001'
  _LISTDATACONNECTORSREQUEST._serialized_start=205
  _LISTDATACONNECTORSREQUEST._serialized_end=398
  _LISTDATACONNECTORSRESPONSE._serialized_start=400
  _LISTDATACONNECTORSRESPONSE._serialized_end=513
  _DELETEDATACONNECTORREQUEST._serialized_start=516
  _DELETEDATACONNECTORREQUEST._serialized_end=649
  _DELETEDATACONNECTORRESPONSE._serialized_start=651
  _DELETEDATACONNECTORRESPONSE._serialized_end=680
  _CREATEDATACONNECTORREQUEST._serialized_start=682
  _CREATEDATACONNECTORREQUEST._serialized_end=803
  _CREATEDATACONNECTORRESPONSE._serialized_start=805
  _CREATEDATACONNECTORRESPONSE._serialized_end=922
  _GETDATACONNECTORREQUEST._serialized_start=925
  _GETDATACONNECTORREQUEST._serialized_end=1104
  _GETDATACONNECTORRESPONSE._serialized_start=1106
  _GETDATACONNECTORRESPONSE._serialized_end=1215
  _DATACONNECTORSSERVICE._serialized_start=1218
  _DATACONNECTORSSERVICE._serialized_end=1841
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strmprivacy/api/purpose_mapping/v1/purpose_mapping_v1.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from strmprivacy.api.entities.v1 import entities_v1_pb2 as strmprivacy_dot_api_dot_entities_dot_v1_dot_entities__v1__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n;strmprivacy/api/purpose_mapping/v1/purpose_mapping_v1.proto\x12\"strmprivacy.api.purpose_mapping.v1\x1a\x1fgoogle/api/field_behavior.proto\x1a-strmprivacy/api/entities/v1/entities_v1.proto\x1a\x17validate/validate.proto\"\x1c\n\x1aListPurposeMappingsRequest\"u\n\x1bListPurposeMappingsResponse\x12V\n\x10purpose_mappings\x18\x01 \x03(\x0b\x32+.strmprivacy.api.entities.v1.PurposeMappingR\x0fpurposeMappings\"}\n\x1b\x43reatePurposeMappingRequest\x12^\n\x0fpurpose_mapping\x18\x01 \x01(\x0b\x32+.strmprivacy.api.entities.v1.PurposeMappingB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\x0epurposeMapping\"y\n\x1c\x43reatePurposeMappingResponse\x12Y\n\x0fpurpose_mapping\x18\x01 \x01(\x0b\x32+.strmprivacy.api.entities.v1.PurposeMappingB\x03\xe0\x41\x02R\x0epurposeMapping\"9\n\x18GetPurposeMappingRequest\x12\x1d\n\x05level\x18\x01 \x01(\x05\x42\x07\xfa\x42\x04\x1a\x02(\x00R\x05level\"v\n\x19GetPurposeMappingResponse\x12Y\n\x0fpurpose_mapping\x18\x01 \x01(\x0b\x32+.strmprivacy.api.entities.v1.PurposeMappingB\x03\xe0\x41\x02R\x0epurposeMapping2\xdf\x03\n\x15PurposeMappingService\x12\x96\x01\n\x13ListPurposeMappings\x12>.strmprivacy.api.purpose_mapping.v1.ListPurposeMappingsRequest\x1a?.strmprivacy.api.purpose_mapping.v1.ListPurposeMappingsResponse\x12\x90\x01\n\x11GetPurposeMapping\x12<.strmprivacy.api.purpose_mapping.v1.GetPurposeMappingRequest\x1a=.strmprivacy.api.purpose_mapping.v1.GetPurposeMappingResponse\x12\x99\x01\n\x14\x43reatePurposeMapping\x12?.strmprivacy.api.purpose_mapping.v1.CreatePurposeMappingRequest\x1a@.strmprivacy.api.purpose_mapping.v1.CreatePurposeMappingResponseB~\n%io.strmprivacy.api.purpose_mapping.v1P\x01ZSgithub.com/strmprivacy/api-definitions-go/v2/api/purpose_mapping/v1;purpose_mappingb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'strmprivacy.api.purpose_mapping.v1.purpose_mapping_v1_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n%io.strmprivacy.api.purpose_mapping.v1P\001ZSgithub.com/strmprivacy/api-definitions-go/v2/api/purpose_mapping/v1;purpose_mapping'
  _CREATEPURPOSEMAPPINGREQUEST.fields_by_name['purpose_mapping']._options = None
  _CREATEPURPOSEMAPPINGREQUEST.fields_by_name['purpose_mapping']._serialized_options = b'\372B\005\212\001\002\020\001'
  _CREATEPURPOSEMAPPINGRESPONSE.fields_by_name['purpose_mapping']._options = None
  _CREATEPURPOSEMAPPINGRESPONSE.fields_by_name['purpose_mapping']._serialized_options = b'\340A\002'
  _GETPURPOSEMAPPINGREQUEST.fields_by_name['level']._options = None
  _GETPURPOSEMAPPINGREQUEST.fields_by_name['level']._serialized_options = b'\372B\004\032\002(\000'
  _GETPURPOSEMAPPINGRESPONSE.fields_by_name['purpose_mapping']._options = None
  _GETPURPOSEMAPPINGRESPONSE.fields_by_name['purpose_mapping']._serialized_options = b'\340A\002'
  _LISTPURPOSEMAPPINGSREQUEST._serialized_start=204
  _LISTPURPOSEMAPPINGSREQUEST._serialized_end=232
  _LISTPURPOSEMAPPINGSRESPONSE._serialized_start=234
  _LISTPURPOSEMAPPINGSRESPONSE._serialized_end=351
  _CREATEPURPOSEMAPPINGREQUEST._serialized_start=353
  _CREATEPURPOSEMAPPINGREQUEST._serialized_end=478
  _CREATEPURPOSEMAPPINGRESPONSE._serialized_start=480
  _CREATEPURPOSEMAPPINGRESPONSE._serialized_end=601
  _GETPURPOSEMAPPINGREQUEST._serialized_start=603
  _GETPURPOSEMAPPINGREQUEST._serialized_end=660
  _GETPURPOSEMAPPINGRESPONSE._serialized_start=662
  _GETPURPOSEMAPPINGRESPONSE._serialized_end=780
  _PURPOSEMAPPINGSERVICE._serialized_start=783
  _PURPOSEMAPPINGSERVICE._serialized_end=1262
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from strmprivacy.api.customer_entity_versions.v1 import customer_entity_versions_v1_pb2 as strmprivacy_dot_api_dot_customer__entity__versions_dot_v1_dot_customer__entity__versions__v1__pb2


class CustomerEntityVersionsServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetBatchExporterImage = channel.unary_unary(
                '/strmprivacy.api.customer_entity_versions.v1.CustomerEntityVersionsService/GetBatchExporterImage',
                request_serializer=strmprivacy_dot_api_dot_customer__entity__versions_dot_v1_dot_customer__entity__versions__v1__pb2.GetBatchExporterImageRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_customer__entity__versions_dot_v1_dot_customer__entity__versions__v1__pb2.GetBatchExporterImageResponse.FromString,
                )
        self.GetKafkaExporterImage = channel.unary_unary(
                '/strmprivacy.api.customer_entity_versions.v1.CustomerEntityVersionsService/GetKafkaExporterImage',
                request_serializer=strmprivacy_dot_api_dot_customer__entity__versions_dot_v1_dot_customer__entity__versions__v1__pb2.GetKafkaExporterImageRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_customer__entity__versions_dot_v1_dot_customer__entity__versions__v1__pb2.GetKafkaExporterImageResponse.FromString,
                )
        self.GetDecrypterImage = channel.unary_unary(
                '/strmprivacy.api.customer_entity_versions.v1.CustomerEntityVersionsService/GetDecrypterImage',
                request_serializer=strmprivacy_dot_api_dot_customer__entity__versions_dot_v1_dot_customer__entity__versions__v1__pb2.GetDecrypterImageRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_customer__entity__versions_dot_v1_dot_customer__entity__versions__v1__pb2.GetDecrypterImageResponse.FromString,
                )
        self.GetBatchJobRunnerImage = channel.unary_unary(
                '/strmprivacy.api.customer_entity_versions.v1.CustomerEntityVersionsService/GetBatchJobRunnerImage',
                request_serializer=strmprivacy_dot_api_dot_customer__entity__versions_dot_v1_dot_customer__entity__versions__v1__pb2.GetBatchJobRunnerImageRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_customer__entity__versions_dot_v1_dot_customer__entity__versions__v1__pb2.GetBatchJobRunnerImageResponse.FromString,
                )


class CustomerEntityVersionsServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def GetBatchExporterImage(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetKafkaExporterImage(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDecrypterImage(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetBatchJobRunnerImage(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_CustomerEntityVersionsServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetBatchExporterImage': grpc.unary_unary_rpc_method_handler(
                    servicer.GetBatchExporterImage,
                    request_deserializer=strmprivacy_dot_api_dot_customer__entity__versions_dot_v1_dot_customer__entity__versions__v1__pb2.GetBatchExporterImageRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_customer__entity__versions_dot_v1_dot_customer__entity__versions__v1__pb2.GetBatchExporterImageResponse.SerializeToString,
            ),
            'GetKafkaExporterImage': grpc.unary_unary_rpc_method_handler(
                    servicer.GetKafkaExporterImage,
                    request_deserializer=strmprivacy_dot_api_dot_customer__entity__versions_dot_v1_dot_customer__entity__versions__v1__pb2.GetKafkaExporterImageRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_customer__entity__versions_dot_v1_dot_customer__entity__versions__v1__pb2.GetKafkaExporterImageResponse.SerializeToString,
            ),
            'GetDecrypterImage': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDecrypterImage,
                    request_deserializer=strmprivacy_dot_api_dot_customer__entity__versions_dot_v1_dot_customer__entity__versions__v1__pb2.GetDecrypterImageRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_customer__entity__versions_dot_v1_dot_customer__entity__versions__v1__pb2.GetDecrypterImageResponse.SerializeToString,
            ),
            'GetBatchJobRunnerImage': grpc.unary_unary_rpc_method_handler(
                    servicer.GetBatchJobRunnerImage,
                    request_deserializer=strmprivacy_dot_api_dot_customer__entity__versions_dot_v1_dot_customer__entity__versions__v1__pb2.GetBatchJobRunnerImageRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_customer__entity__versions_dot_v1_dot_customer__entity__versions__v1__pb2.GetBatchJobRunnerImageResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'strmprivacy.api.customer_entity_versions.v1.CustomerEntityVersionsService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class CustomerEntityVersionsService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def GetBatchExporterImage(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.customer_entity_versions.v1.CustomerEntityVersionsService/GetBatchExporterImage',
            strmprivacy_dot_api_dot_customer__entity__versions_dot_v1_dot_customer__entity__versions__v1__pb2.GetBatchExporterImageRequest.SerializeToString,
            strmprivacy_dot_api_dot_customer__entity__versions_dot_v1_dot_customer__entity__versions__v1__pb2.GetBatchExporterImageResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetKafkaExporterImage(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.customer_entity_versions.v1.CustomerEntityVersionsService/GetKafkaExporterImage',
            strmprivacy_dot_api_dot_customer__entity__versions_dot_v1_dot_customer__entity__versions__v1__pb2.GetKafkaExporterImageRequest.SerializeToString,
            strmprivacy_dot_api_dot_customer__entity__versions_dot_v1_dot_customer__entity__versions__v1__pb2.GetKafkaExporterImageResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetDecrypterImage(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.customer_entity_versions.v1.CustomerEntityVersionsService/GetDecrypterImage',
            strmprivacy_dot_api_dot_customer__entity__versions_dot_v1_dot_customer__entity__versions__v1__pb2.GetDecrypterImageRequest.SerializeToString,
            strmprivacy_dot_api_dot_customer__entity__versions_dot_v1_dot_customer__entity__versions__v1__pb2.GetDecrypterImageResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetBatchJobRunnerImage(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.customer_entity_versions.v1.CustomerEntityVersionsService/GetBatchJobRunnerImage',
            strmprivacy_dot_api_dot_customer__entity__versions_dot_v1_dot_customer__entity__versions__v1__pb2.GetBatchJobRunnerImageRequest.SerializeToString,
            strmprivacy_dot_api_dot_customer__entity__versions_dot_v1_dot_customer__entity__versions__v1__pb2.GetBatchJobRunnerImageResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
